@@ -1,8 +1,11 @@
-/*  $Id: configdata.h,v 1.6 1998/09/14 06:13:51 src Exp $
+/*  $Id: configdata.h,v 1.7 1999/03/07 15:41:31 src Exp $
  *
  *  extracted from INN version 2.0
  *
  *  $Log: configdata.h,v $
+ *  Revision 1.7  1999/03/07 15:41:31  src
+ *  Removed DBZ_VERSION from configuration
+ *
  *  Revision 1.6  1998/09/14 06:13:51  src
  *  Picked RETSIGTYPE from config.h
  *
@@ -17,6 +20,7 @@
 
 #include "common.h"
 #include "proto.h"
+#include "../config.h"
 
 typedef int BOOL;
 #ifndef TRUE
