@@ -1,4 +1,4 @@
-/* $Id: dbz-v3.c,v 1.7 1998/09/02 06:50:25 src Exp $
+/* $Id: dbz-v3.c,v 1.12 1999/03/07 15:41:32 src Exp $
 
 dbz.c  V3.4
 
@@ -27,14 +27,27 @@ tricks mmap() uses.  That way, all kinds of software can get more efficient
 *without* having non-portable grunge like mmap() hacked into it.
 
 $Log: dbz-v3.c,v $
+Revision 1.12  1999/03/07 15:41:32  src
+Removed DBZ_VERSION from configuration
+
+Revision 1.11  1999/03/07 14:58:14  src
+Read newsconfig supported. Storage API supported.
+
+Revision 1.10  1999/03/05 11:20:30  src
+Delayed decision of dbz v3 vz. 6 to runtime.
+
+Revision 1.9  1999/03/04 17:18:36  src
+Split between dbz v3 and v6 improved
+
+Revision 1.8  1999/03/04 16:19:48  src
+Renamed dbz v3, and introduced DBZV3_READONLY
+
 Revision 1.7  1998/09/02 06:50:25  src
 NewsX version 1.0
 
 Revision 1.6  1998/07/12 10:27:12  src
 Moved a comment
 
-Changed fopen() to fopen_W() to support read/only mode *EK*
-
 */
 
 #include <stdlib.h>
@@ -45,7 +58,7 @@ Changed fopen() to fopen_W() to support read/only mode *EK*
 #include <memory.h>
 #include <errno.h>
 
-#include "dbz.h"
+#include "dbz-v3.h"
 
 /*
  * #ifdef index.  "LIA" = "leave it alone unless you know what you're doing".
@@ -53,7 +66,7 @@ Changed fopen() to fopen_W() to support read/only mode *EK*
  * FUNNYSEEKS   SEEK_SET is not 0, get it from <unistd.h>
  * INDEX_SIZE   backward compatibility with old dbz; avoid using this
  * NMEMORY      number of days of memory for use in sizing new table (LIA)
- * INCORE       backward compatibility with old dbz; use dbzincore() instead
+ * INCORE       backward compatibility with old dbz; use dbzv3_incore() instead
  * DBZDEBUG     enable debugging
  * DEFSIZE      default table size (not as critical as in old dbz)
  * OLDBNEWS     default case mapping as in old B News; set NOBUFFER
@@ -216,7 +229,11 @@ struct dbzconfig {
 static struct dbzconfig conf;
 static int getconf();
 static long getno();
+
+#if !DBZV3_READONLY
 static int putconf();
+#endif /* !DBZV3_READONLY */
+
 static void mybytemap();
 static of_t bytemap();
 
@@ -224,14 +241,14 @@ static of_t bytemap();
  * For a program that makes many, many references to the database, it
  * is a large performance win to keep the table in core, if it will fit.
  * Note that this does hurt robustness in the event of crashes, and
- * dbzdbmclose() *must* be called to flush the in-core database to disk.
+ * dbzv3_dbmclose() *must* be called to flush the in-core database to disk.
  * The code is prepared to deal with the possibility that there isn't
  * enough memory.  There *is* an assumption that a size_t is big enough
- * to hold the size (in bytes) of one table, so dbzdbminit() tries to figure
+ * to hold the size (in bytes) of one table, so dbzv3_dbminit() tries to figure
  * out whether this is possible first.
  *
- * The preferred way to ask for an in-core table is to do dbzincore(1)
- * before dbzdbminit().  The default is not to do it, although -DINCORE
+ * The preferred way to ask for an in-core table is to do dbzv3_incore(1)
+ * before dbzv3_dbminit(). The default is not to do it, although -DINCORE
  * overrides this for backward compatibility with old dbz.
  *
  * We keep only the first table in core.  This greatly simplifies the
@@ -248,7 +265,9 @@ static int incore = 0;
  * Making the in-core table write-through is a win in some odd situations
  * where one is doing much reading and very little writing.
  */
+#if !DBZV3_READONLY
 static int writethrough = 0;
+#endif
 
 /*
  * Stdio buffer for .pag reads.  Buffering more than about 16 does not help
@@ -285,7 +304,9 @@ static char basebuf[SHISTBUF];          /* only needed if _IOFBF exists */
  * bits on the descriptor.  The callback routine gets a FILE * as its
  * parameter, and must not mess with it in dbz-visible ways.
  */
+#if !DBZV3_READONLY
 static void (*callback)() = NULL;
+#endif
 
 /*
  * Data structure for recording info about searches.
@@ -306,8 +327,6 @@ static void start();
 #define FRESH   ((struct searcher *)NULL)
 static of_t search();
 #define NOTFOUND        ((of_t)-1)
-static int okayvalue();
-static int set();
 
 /*
  * Arguably the searcher struct for a given routine ought to be local to
@@ -346,9 +365,15 @@ static long hash();
 static void crcinit();
 static char *cipoint();
 static char *mapcase();
-static int isprime();
 static FILE *latebase();
 
+#if !DBZV3_READONLY
+static int okayvalue();
+static int set();
+static int isprime();
+static int putcore();
+#endif
+
 /* file-naming stuff */
 static char dir[] = ".dir";
 static char pag[] = ".pag";
@@ -358,21 +383,24 @@ static char *enstring();
 static FILE *basef;             /* descriptor for base file */
 static char *basefname;         /* name for not-yet-opened base file */
 static FILE *dirf;              /* descriptor for .dir file */
-static int dirronly;            /* dirf open read-only? */
 static FILE *pagf = NULL;       /* descriptor for .pag file */
 static of_t pagpos;             /* posn in pagf; only search may set != -1 */
-static int pagronly;            /* pagf open read-only? */
 static of_t *corepag;           /* incore version of .pag file, if any */
 static FILE *bufpagf;           /* well-buffered pagf, for incore rewrite */
 static of_t *getcore();
-static int putcore();
-static int written;             /* has a store() been done? */
 
+#if !DBZV3_READONLY
+static int dirronly;            /* dirf open read-only? */
+static int pagronly;            /* pagf open read-only? */
+static int written;             /* has a store() been done? */
+#endif
+
+#if !DBZV3_READONLY
 /*
- - dbzfresh - set up a new database, no historical info
+ - dbzv3_fresh - set up a new database, no historical info
  */
 int                             /* 0 success, -1 failure */
-dbzfresh(name, size, fs, cmap, tagmask)
+dbzv3_fresh(name, size, fs, cmap, tagmask)
 char *name;                     /* base name; .dir and .pag must exist */
 long size;                      /* table size (0 means default) */
 int fs;                         /* field-separator character in base file */
@@ -385,11 +413,11 @@ of_t tagmask;                   /* 0 default, 1 no tags */
 	register FILE *f;
 
 	if (pagf != NULL) {
-		DEBUG(("dbzfresh: database already open\n"));
+		DEBUG(("dbzv3_fresh: database already open\n"));
 		return(-1);
 	}
 	if (size != 0 && size < 2) {
-		DEBUG(("dbzfresh: preposterous size (%ld)\n", size));
+		DEBUG(("dbzv3_fresh: preposterous size (%ld)\n", size));
 		return(-1);
 	}
 
@@ -418,7 +446,7 @@ of_t tagmask;                   /* 0 default, 1 no tags */
 		c.casemap = DEFCASE;
 		break;
 	default:
-		DEBUG(("dbzfresh case map `%c' unknown\n", cmap));
+		DEBUG(("dbzv3_fresh case map `%c' unknown\n", cmap));
 		return(-1);
 		break;
 	}
@@ -446,10 +474,10 @@ of_t tagmask;                   /* 0 default, 1 no tags */
 	fn = enstring(name, dir);
 	if (fn == NULL)
 		return(-1);
-	f = fopen_W(fn, "w");
+	f = fopen(fn, "w");
 	free(fn);
 	if (f == NULL) {
-		DEBUG(("dbzfresh: unable to write config\n"));
+		DEBUG(("dbzv3_fresh: unable to write config\n"));
 		return(-1);
 	}
 	if (putconf(f, &c) < 0) {
@@ -457,7 +485,7 @@ of_t tagmask;                   /* 0 default, 1 no tags */
 		return(-1);
 	}
 	if (fclose(f) == EOF) {
-		DEBUG(("dbzfresh: fclose failure\n"));
+		DEBUG(("dbzv3_fresh: fclose failure\n"));
 		return(-1);
 	}
 
@@ -465,38 +493,38 @@ of_t tagmask;                   /* 0 default, 1 no tags */
 	fn = enstring(name, pag);
 	if (fn == NULL)
 		return(-1);
-	f = fopen_W(fn, "w");
+	f = fopen(fn, "w");
 	free(fn);
 	if (f == NULL) {
-		DEBUG(("dbzfresh: unable to create/truncate .pag file\n"));
+		DEBUG(("dbzv3_fresh: unable to create/truncate .pag file\n"));
 		return(-1);
 	} else
 		(void) fclose(f);
 
-	/* and punt to dbzdbminit for the hard work */
-	return(dbzdbminit(name));
+	/* and punt to dbzv3_dbminit for the hard work */
+	return(dbzv3_dbminit(name));
 }
 
 /*
- - dbzsize - what's a good table size to hold this many entries?
+ - dbzv3_size - what's a good table size to hold this many entries?
  */
 long
-dbzsize(contents)
+dbzv3_size(contents)
 long contents;                  /* 0 means what's the default */
 {
 	register long n;
 
 	if (contents <= 0) {    /* foulup or default inquiry */
-		DEBUG(("dbzsize: preposterous input (%ld)\n", contents));
+		DEBUG(("dbzv3_size: preposterous input (%ld)\n", contents));
 		return(DEFSIZE);
 	}
 	n = (contents/2)*3;     /* try to keep table at most 2/3 full */
 	if (!(n&01))            /* make it odd */
 		n++;
-	DEBUG(("dbzsize: tentative size %ld\n", n));
+	DEBUG(("dbzv3_size: tentative size %ld\n", n));
 	while (!isprime(n))     /* and look for a prime */
 		n += 2;
-	DEBUG(("dbzsize: final size %ld\n", n));
+	DEBUG(("dbzv3_size: final size %ld\n", n));
 
 	return(n);
 }
@@ -537,12 +565,12 @@ register long x;
 }
 
 /*
- - dbztagmask - what's a good tag mask for a file this size?
+ - dbzv3_tagmask - what's a good tag mask for a file this size?
  *
  * This assumes that TAGENB is the high-order bit of a long.
  */
 long
-dbztagmask(filesize)
+dbzv3_tagmask(filesize)
 register long filesize;
 {
 	register long m;
@@ -573,10 +601,10 @@ register long filesize;
 }
 
 /*
- - dbzagain - set up a new database to be a rebuild of an old one
+ - dbzv3_again - set up a new database to be a rebuild of an old one
  */
 int                             /* 0 success, -1 failure */
-dbzagain(name, oldname)
+dbzv3_again(name, oldname)
 char *name;                     /* base name; .dir and .pag must exist */
 char *oldname;                  /* base name; all must exist */
 {
@@ -589,7 +617,7 @@ char *oldname;                  /* base name; all must exist */
 	register long newsize;
 
 	if (pagf != NULL) {
-		DEBUG(("dbzagain: database already open\n"));
+		DEBUG(("dbzv3_again: database already open\n"));
 		return(-1);
 	}
 
@@ -600,13 +628,13 @@ char *oldname;                  /* base name; all must exist */
 	f = fopen(fn, "r");
 	free(fn);
 	if (f == NULL) {
-		DEBUG(("dbzagain: can't open old .dir file\n"));
+		DEBUG(("dbzv3_again: can't open old .dir file\n"));
 		return(-1);
 	}
 	i = getconf(f, (FILE *)NULL, &c);
 	(void) fclose(f);
 	if (i < 0) {
-		DEBUG(("dbzagain: getconf failed\n"));
+		DEBUG(("dbzv3_again: getconf failed\n"));
 		return(-1);
 	}
 
@@ -621,7 +649,7 @@ char *oldname;                  /* base name; all must exist */
 			newtable = 1;   /* hasn't got full usage history yet */
 	}
 	if (top == 0) {
-		DEBUG(("dbzagain: old table has no contents!\n"));
+		DEBUG(("dbzv3_again: old table has no contents!\n"));
 		newtable = 1;
 	}
 
@@ -632,7 +660,7 @@ char *oldname;                  /* base name; all must exist */
 	}
 	c.used[0] = 0;
 	c.ntagless[0] = 0;
-	newsize = dbzsize(top);
+	newsize = dbzv3_size(top);
 	if (!newtable || newsize > c.tsize)     /* don't shrink new table */
 		c.tsize = newsize;
 
@@ -652,16 +680,16 @@ char *oldname;                  /* base name; all must exist */
 	fn = enstring(name, dir);
 	if (fn == NULL)
 		return(-1);
-	f = fopen_W(fn, "w");
+	f = fopen(fn, "w");
 	free(fn);
 	if (f == NULL) {
-		DEBUG(("dbzagain: unable to write new .dir\n"));
+		DEBUG(("dbzv3_again: unable to write new .dir\n"));
 		return(-1);
 	}
 	i = putconf(f, &c);
 	(void) fclose(f);
 	if (i < 0) {
-		DEBUG(("dbzagain: putconf failed\n"));
+		DEBUG(("dbzv3_again: putconf failed\n"));
 		return(-1);
 	}
 
@@ -669,26 +697,27 @@ char *oldname;                  /* base name; all must exist */
 	fn = enstring(name, pag);
 	if (fn == NULL)
 		return(-1);
-	f = fopen_W(fn, "w");
+	f = fopen(fn, "w");
 	free(fn);
 	if (f == NULL) {
-		DEBUG(("dbzagain: unable to create/truncate .pag file\n"));
+		DEBUG(("dbzv3_again: unable to create/truncate .pag file\n"));
 		return(-1);
 	} else
 		(void) fclose(f);
 
-	/* and let dbzdbminit do the work */
-	return(dbzdbminit(name));
+	/* and let dbzv3_dbminit do the work */
+	return(dbzv3_dbminit(name));
 }
+#endif /* !DBZV3_READONLY */
 
 /*
- - dbzdbminit - open a database, creating it (using defaults) if necessary
+ - dbzv3_dbminit - open a database, creating it (using defaults) if necessary
  *
  * We try to leave errno set plausibly, to the extent that underlying
- * functions permit this, since many people consult it if dbzdbminit() fails.
+ * functions permit this, since many people consult it if dbzv3_dbminit() fails.
  */
 int                             /* 0 success, -1 failure */
-dbzdbminit(name)
+dbzv3_dbminit(name)
 char *name;
 {
 	register int i;
@@ -697,7 +726,7 @@ char *name;
 	register char *pagfname;
 
 	if (pagf != NULL) {
-		DEBUG(("dbzdbminit: dbzdbminit already called once\n"));
+		DEBUG(("dbzv3_dbminit: already called once\n"));
 		errno = 0;
 		return(-1);
 	}
@@ -706,19 +735,26 @@ char *name;
 	dirfname = enstring(name, dir);
 	if (dirfname == NULL)
 		return(-1);
-	dirf = fopen_W(dirfname, "r+");
+#if !DBZV3_READONLY
+	written = 0;
+	dirf = fopen(dirfname, "r+");
 	if (dirf == NULL) {
 		dirf = fopen(dirfname, "r");
 		dirronly = 1;
 	} else
 		dirronly = 0;
+#else
+	dirf = fopen(dirfname, "r");
+#endif
 	free(dirfname);
 	if (dirf == NULL) {
-		DEBUG(("dbzdbminit: can't open .dir file\n"));
+		DEBUG(("dbzv3_dbminit: can't open .dir file\n"));
 		return(-1);
 	}
+#if !DBZV3_READONLY
 	if (callback != NULL)
 		(*callback)(dirf);
+#endif
 
 	/* open the .pag file */
 	pagfname = enstring(name, pag);
@@ -726,20 +762,24 @@ char *name;
 		(void) fclose(dirf);
 		return(-1);
 	}
-	pagf = fopen_W(pagfname, "r+b");
+#if !DBZV3_READONLY
+	pagf = fopen(pagfname, "r+b");
 	if (pagf == NULL) {
 		pagf = fopen(pagfname, "rb");
-		if (pagf == NULL) {
-			DEBUG(("dbzdbminit: .pag open failed\n"));
-			(void) fclose(dirf);
-			free(pagfname);
-			return(-1);
-		}
 		pagronly = 1;
 	} else if (dirronly)
 		pagronly = 1;
 	else
 		pagronly = 0;
+#else
+	pagf = fopen(pagfname, "rb");
+#endif
+	if (pagf == NULL) {
+		DEBUG(("dbzv3_dbminit: .pag open failed\n"));
+		(void) fclose(dirf);
+		free(pagfname);
+		return(-1);
+	}
 #ifdef NOBUFFER
 	/*
 	 * B News does not do adequate locking on its database accesses.
@@ -755,13 +795,15 @@ char *name;
 #endif
 	pagpos = -1;
 	/* don't free pagfname, need it below */
+#if !DBZV3_READONLY
 	if (callback != NULL)
 		(*callback)(pagf);
+#endif
 
 	/* open the base file */
 	basef = fopen(name, "r");
 	if (basef == NULL) {
-		DEBUG(("dbzdbminit: basefile open failed\n"));
+		DEBUG(("dbzv3_dbminit: basefile open failed\n"));
 		basefname = enstring(name, "");
 		if (basefname == NULL) {
 			(void) fclose(pagf);
@@ -776,12 +818,14 @@ char *name;
 	if (basef != NULL)
 		(void) setvbuf(basef, basebuf, _IOFBF, sizeof(basebuf));
 #endif
+#if !DBZV3_READONLY
 	if (callback != NULL)
 		(*callback)(basef);
+#endif
 
 	/* pick up configuration */
 	if (getconf(dirf, pagf, &conf) < 0) {
-		DEBUG(("dbzdbminit: getconf failure\n"));
+		DEBUG(("dbzv3_dbminit: getconf failure\n"));
 		(void) fclose(basef);
 		(void) fclose(pagf);
 		(void) fclose(dirf);
@@ -802,11 +846,17 @@ char *name;
 	/* get first table into core, if it looks desirable and feasible */
 	s = (size_t)conf.tsize * SOF;
 	if (incore && (of_t)(s/SOF) == conf.tsize) {
+#if !DBZV3_READONLY
 		bufpagf = fopen(pagfname, (pagronly) ? "rb" : "r+b");
+#else
+		bufpagf = fopen(pagfname, "rb");
+#endif
 		if (bufpagf != NULL) {
 			corepag = getcore(bufpagf);
+#if !DBZV3_READONLY
 			if (callback != NULL)
 				(*callback)(bufpagf);
+#endif
 		}
 	} else {
 		bufpagf = NULL;
@@ -816,9 +866,8 @@ char *name;
 
 	/* misc. setup */
 	crcinit();
-	written = 0;
 	prevp = FRESH;
-	DEBUG(("dbzdbminit: succeeded\n"));
+	DEBUG(("dbzv3_dbminit: succeeded\n"));
 	return(0);
 }
 
@@ -843,34 +892,36 @@ char *s2;
 }
 
 /*
- - dbzdbmclose - close a database
+ - dbzv3_dbmclose - close a database
  */
 int
-dbzdbmclose()
+dbzv3_dbmclose()
 {
 	register int ret = 0;
 
 	if (pagf == NULL) {
-		DEBUG(("dbzdbmclose: not opened!\n"));
+		DEBUG(("dbzv3_dbmclose: not opened!\n"));
 		return(-1);
 	}
 
 	if (fclose(pagf) == EOF) {
-		DEBUG(("dbzdbmclose: fclose(pagf) failed\n"));
+		DEBUG(("dbzv3_dbmclose: fclose(pagf) failed\n"));
 		ret = -1;
 	}
-	pagf = basef;           /* ensure valid pointer; dbzsync checks it */
-	if (dbzsync() < 0)
+	pagf = basef;           /* ensure valid pointer; dbzv3_sync checks it */
+#if !DBZV3_READONLY
+	if (dbzv3_sync() < 0)
 		ret = -1;
+#endif
 	if (bufpagf != NULL && fclose(bufpagf) == EOF) {
-		DEBUG(("dbzdbmclose: fclose(bufpagf) failed\n"));
+		DEBUG(("dbzv3_dbmclose: fclose(bufpagf) failed\n"));
 		ret = -1;
 	}
 	if (corepag != NULL)
 		free((char *)corepag);
 	corepag = NULL;
 	if (fclose(basef) == EOF) {
-		DEBUG(("dbzdbmclose: fclose(basef) failed\n"));
+		DEBUG(("dbzv3_dbmclose: fclose(basef) failed\n"));
 		ret = -1;
 	}
 	if (basefname != NULL)
@@ -878,24 +929,25 @@ dbzdbmclose()
 	basef = NULL;
 	pagf = NULL;
 	if (fclose(dirf) == EOF) {
-		DEBUG(("dbzdbmclose: fclose(dirf) failed\n"));
+		DEBUG(("dbzv3_dbmclose: fclose(dirf) failed\n"));
 		ret = -1;
 	}
 
-	DEBUG(("dbzdbmclose: %s\n", (ret == 0) ? "succeeded" : "failed"));
+	DEBUG(("dbzv3_dbmclose: %s\n", (ret == 0) ? "succeeded" : "failed"));
 	return(ret);
 }
 
+#if !DBZV3_READONLY
 /*
- - dbzsync - push all in-core data out to disk
+ - dbzv3_sync - push all in-core data out to disk
  */
 int
-dbzsync()
+dbzv3_sync()
 {
 	register int ret = 0;
 
 	if (pagf == NULL) {
-		DEBUG(("dbzsync: not opened!\n"));
+		DEBUG(("dbzv3_sync: not opened!\n"));
 		return(-1);
 	}
 	if (!written)
@@ -903,7 +955,7 @@ dbzsync()
 
 	if (corepag != NULL && !writethrough) {
 		if (putcore(corepag, bufpagf) < 0) {
-			DEBUG(("dbzsync: putcore failed\n"));
+			DEBUG(("dbzv3_sync: putcore failed\n"));
 			ret = -1;
 		}
 	}
@@ -911,87 +963,88 @@ dbzsync()
 		if (putconf(dirf, &conf) < 0)
 			ret = -1;
 
-	DEBUG(("dbzsync: %s\n", (ret == 0) ? "succeeded" : "failed"));
+	DEBUG(("dbzv3_sync: %s\n", (ret == 0) ? "succeeded" : "failed"));
 	return(ret);
 }
 
 /*
- - dbzcancel - cancel writing of in-core data
+ - dbzv3_cancel - cancel writing of in-core data
  * Mostly for use from child processes.
  * Note that we don't need to futz around with stdio buffers, because we
  * always fflush them immediately anyway and so they never have stale data.
  */
 int
-dbzcancel()
+dbzv3_cancel()
 {
 	if (pagf == NULL) {
-		DEBUG(("dbzcancel: not opened!\n"));
+		DEBUG(("dbzv3_cancel: not opened!\n"));
 		return(-1);
 	}
 
 	written = 0;
 	return(0);
 }
+#endif /* !DBZV3_READONLY */
 
 /*
- - dbzfetch - fetch() with case mapping built in
+ - dbzv3_fetch - fetch() with case mapping built in
  */
-datum
-dbzfetch(key)
-datum key;
+dbzv3_datum
+dbzv3_fetch(key)
+dbzv3_datum key;
 {
-	char buffer[DBZMAXKEY + 1];
-	datum mappedkey;
+	char buffer[DBZV3_MAXKEY + 1];
+	dbzv3_datum mappedkey;
 	register size_t keysize;
 
-	DEBUG(("dbzfetch: (%s)\n", key.dptr));
+	DEBUG(("dbzv3_fetch: (%s)\n", key.dptr));
 
-	/* Key is supposed to be less than DBZMAXKEY */
+	/* Key is supposed to be less than DBZV3_MAXKEY */
 	keysize = key.dsize;
-	if (keysize >= DBZMAXKEY) {
-		keysize = DBZMAXKEY;
-		DEBUG(("keysize is %d - truncated to %d\n", key.dsize, DBZMAXKEY));
+	if (keysize >= DBZV3_MAXKEY) {
+		keysize = DBZV3_MAXKEY;
+		DEBUG(("keysize is %d - truncated to %d\n", key.dsize, DBZV3_MAXKEY));
 	}
 
 	mappedkey.dptr = mapcase(buffer, key.dptr, keysize);
 	buffer[keysize] = '\0'; /* just a debug aid */
 	mappedkey.dsize = keysize;
 
-	return(dbzdbmfetch(mappedkey));
+	return(dbzv3_dbmfetch(mappedkey));
 }
 
 /*
- - dbzdbmfetch - get an entry from the database
+ - dbzv3_dbmfetch - get an entry from the database
  *
  * Disgusting fine point, in the name of backward compatibility:  if the
  * last character of "key" is a NUL, that character is (effectively) not
  * part of the comparison against the stored keys.
  */
-datum                           /* dptr NULL, dsize 0 means failure */
-dbzdbmfetch(key)
-datum key;
+dbzv3_datum                     /* dptr NULL, dsize 0 means failure */
+dbzv3_dbmfetch(key)
+dbzv3_datum key;
 {
-	char buffer[DBZMAXKEY + 1];
+	char buffer[DBZV3_MAXKEY + 1];
 	static of_t key_ptr;            /* return value points here */
-	datum output;
+	dbzv3_datum output;
 	register size_t keysize;
 	register size_t cmplen;
 	register char *sepp;
 
-	DEBUG(("dbzdbmfetch: (%s)\n", key.dptr));
+	DEBUG(("dbzv3_dbmfetch: (%s)\n", key.dptr));
 	output.dptr = NULL;
 	output.dsize = 0;
 	prevp = FRESH;
 
-	/* Key is supposed to be less than DBZMAXKEY */
+	/* Key is supposed to be less than DBZV3_MAXKEY */
 	keysize = key.dsize;
-	if (keysize >= DBZMAXKEY) {
-		keysize = DBZMAXKEY;
-		DEBUG(("keysize is %d - truncated to %d\n", key.dsize, DBZMAXKEY));
+	if (keysize >= DBZV3_MAXKEY) {
+		keysize = DBZV3_MAXKEY;
+		DEBUG(("keysize is %d - truncated to %d\n", key.dsize, DBZV3_MAXKEY));
 	}
 
 	if (pagf == NULL) {
-		DEBUG(("dbzdbmfetch: database not open!\n"));
+		DEBUG(("dbzv3_dbmfetch: database not open!\n"));
 		return(output);
 	} else if (basef == NULL) {     /* basef didn't exist yet */
 		basef = latebase();
@@ -1011,11 +1064,11 @@ datum key;
 
 		/* fetch the key */
 		if (fseek(basef, key_ptr, SEEK_SET) != 0) {
-			DEBUG(("dbzdbmfetch: seek failed\n"));
+			DEBUG(("dbzv3_dbmfetch: seek failed\n"));
 			return(output);
 		}
 		if (fread(buffer, 1, keysize, basef) != keysize) {
-			DEBUG(("dbzdbmfetch: read failed\n"));
+			DEBUG(("dbzv3_dbmfetch: read failed\n"));
 			return(output);
 		}
 
@@ -1023,7 +1076,7 @@ datum key;
 		buffer[keysize] = '\0';         /* terminated for DEBUG */
 		(void) mapcase(buffer, buffer, keysize);
 #if 0 /*EK*/
-		DEBUG(("dbzdbmfetch: buffer (%s) looking for (%s) size = %d\n", 
+		DEBUG(("dbzv3_dbmfetch: buffer (%s) looking for (%s) size = %d\n",
 						buffer, key.dptr, keysize));
 #endif
 		if (memcmp(key.dptr, buffer, cmplen) == 0 &&
@@ -1031,13 +1084,13 @@ datum key;
 			/* we found it */
 			output.dptr = (char *)&key_ptr;
 			output.dsize = SOF;
-			DEBUG(("dbzdbmfetch: successful\n"));
+			DEBUG(("dbzv3_dbmfetch: successful\n"));
 			return(output);
 		}
 	}
 
 	/* we didn't find it */
-	DEBUG(("dbzdbmfetch: found nothing\n")); /*EK*/
+	DEBUG(("dbzv3_dbmfetch: found nothing\n")); /*EK*/
 	prevp = &srch;                  /* remember where we stopped */
 	return(output);
 }
@@ -1064,30 +1117,33 @@ latebase()
 #ifdef _IOFBF
 		(void) setvbuf(it, basebuf, _IOFBF, sizeof(basebuf));
 #endif
+#if !DBZV3_READONLY
 		if (callback != NULL)
 			(*callback)(it);
+#endif
 	}
 	return(it);
 }
 
 /*
- - dbzstore - store() with case mapping built in
+ - dbzv3_store - store() with case mapping built in
  */
+#if !DBZV3_READONLY
 int
-dbzstore(key, data)
-datum key;
-datum data;
+dbzv3_store(key, data)
+dbzv3_datum key;
+dbzv3_datum data;
 {
-	char buffer[DBZMAXKEY + 1];
-	datum mappedkey;
+	char buffer[DBZV3_MAXKEY + 1];
+	dbzv3_datum mappedkey;
 	register size_t keysize;
 
-	DEBUG(("dbzstore: (%s)\n", key.dptr));
+	DEBUG(("dbzv3_store: (%s)\n", key.dptr));
 
-	/* Key is supposed to be less than DBZMAXKEY */
+	/* Key is supposed to be less than DBZV3_MAXKEY */
 	keysize = key.dsize;
-	if (keysize >= DBZMAXKEY) {
-		DEBUG(("dbzstore: key size too big (%d)\n", key.dsize));
+	if (keysize >= DBZV3_MAXKEY) {
+		DEBUG(("dbzv3_store: key size too big (%d)\n", key.dsize));
 		return(-1);
 	}
 
@@ -1095,21 +1151,21 @@ datum data;
 	buffer[keysize] = '\0'; /* just a debug aid */
 	mappedkey.dsize = keysize;
 
-	return(dbzdbmstore(mappedkey, data));
+	return(dbzv3_dbmstore(mappedkey, data));
 }
 
 /*
- - dbzdbmstore - add an entry to the database
+ - dbzv3_dbmstore - add an entry to the database
  */
 int                             /* 0 success, -1 failure */
-dbzdbmstore(key, data)
-datum key;
-datum data;
+dbzv3_dbmstore(key, data)
+dbzv3_datum key;
+dbzv3_datum data;
 {
 	of_t value;
 
 	if (pagf == NULL) {
-		DEBUG(("dbzdbmstore: database not open!\n"));
+		DEBUG(("dbzv3_dbmstore: database not open!\n"));
 		return(-1);
 	} else if (basef == NULL) {     /* basef didn't exist yet */
 		basef = latebase();
@@ -1117,23 +1173,23 @@ datum data;
 			return(-1);
 	}
 	if (pagronly) {
-		DEBUG(("dbzdbmstore: database open read-only\n"));
+		DEBUG(("dbzv3_dbmstore: database open read-only\n"));
 		return(-1);
 	}
 	if (data.dsize != SOF) {
-		DEBUG(("dbzdbmstore: value size wrong (%d)\n", data.dsize));
+		DEBUG(("dbzv3_dbmstore: value size wrong (%d)\n", data.dsize));
 		return(-1);
 	}
-	if (key.dsize >= DBZMAXKEY) {
-		DEBUG(("dbzdbmstore: key size too big (%d)\n", key.dsize));
+	if (key.dsize >= DBZV3_MAXKEY) {
+		DEBUG(("dbzv3_dbmstore: key size too big (%d)\n", key.dsize));
 		return(-1);
 	}
 
 	/* copy the value in to ensure alignment */
 	(void) memcpy((char *)&value, data.dptr, SOF);
-	DEBUG(("dbzdbmstore: (%s, %ld)\n", key.dptr, (long)value));
+	DEBUG(("dbzv3_dbmstore: (%s, %ld)\n", key.dptr, (long)value));
 	if (!okayvalue(value)) {
-		DEBUG(("dbzdbmstore: reserved bit or overflow in 0x%lx\n", value));
+		DEBUG(("dbzv3_dbmstore: reserved bit or overflow in 0x%lx\n", value));
 		return(-1);
 	}
 
@@ -1144,16 +1200,16 @@ datum data;
 
 	prevp = FRESH;
 	conf.used[0]++;
-	DEBUG(("dbzdbmstore: used count %ld\n", conf.used[0]));
+	DEBUG(("dbzv3_dbmstore: used count %ld\n", conf.used[0]));
 	written = 1;
 	return(set(&srch, value));
 }
 
 /*
- - dbzincore - control attempts to keep .pag file in core
+ - dbzv3_incore - control attempts to keep .pag file in core
  */
 int                             /* old setting */
-dbzincore(value)
+dbzv3_incore(value)
 int value;
 {
 	register int old = incore;
@@ -1163,10 +1219,10 @@ int value;
 }
 
 /*
- - dbzwritethrough - enable/disable immediate writing to disk of in-core writes
+ - dbzv3_writethrough - enable/disable immediate writing to disk of in-core writes
  */
 int                             /* old setting */
-dbzwritethrough(value)
+dbzv3_writethrough(value)
 int value;
 {
 	register int old = writethrough;
@@ -1176,11 +1232,11 @@ int value;
 }
 
 /*
- - dbzfiledesc - provide hook for doing obscene things to file descriptors
+ - dbzv3_filedesc - provide hook for doing obscene things to file descriptors
  */
 typedef void (*fp)();
 fp
-dbzfiledesc(diddler)
+dbzv3_filedesc(diddler)
 void (*diddler)();              /* NULL means do nothing */
 {
 	register void (*old)() = callback;
@@ -1188,6 +1244,7 @@ void (*diddler)();              /* NULL means do nothing */
 	callback = diddler;
 	return(old);
 }
+#endif /* !DBZV3_READONLY */
 
 /*
  - getconf - get configuration from .dir file
@@ -1341,6 +1398,7 @@ int *ep;
 /*
  - putconf - write configuration to .dir file
  */
+#if !DBZV3_READONLY
 static int                      /* 0 success, -1 failure */
 putconf(f, cp)
 register FILE *f;
@@ -1371,6 +1429,7 @@ register struct dbzconfig *cp;
 	DEBUG(("putconf status %d\n", ret));
 	return(ret);
 }
+#endif /* !DBZV3_READONLY */
 
 /*
  - getcore - try to set up an in-core copy of .pag file
@@ -1408,6 +1467,7 @@ FILE *f;
 /*
  - putcore - try to rewrite an in-core table
  */
+#if !DBZV3_READONLY
 static int                      /* 0 okay, -1 fail */
 putcore(tab, f)
 of_t *tab;
@@ -1421,6 +1481,7 @@ FILE *f;
 	(void) fflush(f);
 	return((ferror(f)) ? -1 : 0);
 }
+#endif /* !DBZV3_READONLY */
 
 /*
  - start - set up to start or restart a search
@@ -1428,7 +1489,7 @@ FILE *f;
 static void
 start(sp, kp, osp)
 register struct searcher *sp;
-register datum *kp;
+register dbzv3_datum *kp;
 register struct searcher *osp;          /* may be FRESH, i.e. NULL */
 {
 	register long h;
@@ -1534,6 +1595,7 @@ register struct searcher *sp;
 	/* NOTREACHED */
 }
 
+#if !DBZV3_READONLY
 /*
  - okayvalue - check that a value can be stored
  */
@@ -1609,6 +1671,7 @@ of_t value;
 	DEBUG(("set: succeeded\n"));
 	return(0);
 }
+#endif /* !DBZV3_READONLY */
 
 /*
  - mybytemap - determine this machine's byte map
@@ -1906,11 +1969,11 @@ size_t siz;
 }
 
 /*
- - dbzdebug - control dbz debugging at run time
+ - dbzv3_debug - control dbz debugging at run time
  */
 #ifdef DBZDEBUG
 int                             /* old value */
-dbzdebug(value)
+dbzv3_debug(value)
 int value;
 {
 	register int old = debug;
@@ -1920,3 +1983,36 @@ int value;
 	return(-1);
 }
 #endif
+
+
+/*EK* extension:
+ *
+ * dbz_version - return the DBZ version number for a database
+ *
+ */
+int                             /* -1 if error, >0 version number */
+dbz_version(name)
+char *name;
+{
+	char *dirfname;
+	FILE *df;
+	int version = -1;
+	int err = 0;
+
+	/* open the .dir file */
+	dirfname = enstring(name, dir);
+	if (dirfname == NULL)
+		return -1;
+
+	df = fopen(dirfname, "r");
+	free(dirfname);
+	if (df == NULL) return -1;
+
+	/* pick up configuration */
+	if (getc(df) == 'd' && getc(df) == 'b' && getc(df) == 'z') {
+		version = getno(df, &err);
+	}
+	fclose(df);
+
+	return version;
+}
