@@ -1,4 +1,4 @@
-/* TAB P   $Id: dbz-v6.c,v 1.12 1999/04/08 10:48:51 src Exp $
+/* TAB P   $Id: dbz-v6.c,v 1.12.2.2 2002/10/01 08:54:58 egil Exp $
 
   dbz.c  V6.1.1
 
@@ -61,6 +61,12 @@ to produce files with holes in them, which is a nuisance.)
 Tagged hash + offset fuzzy technique merged by Sang-yong Suh (Nov, 1997)
 
 $Log: dbz-v6.c,v $
+Revision 1.12.2.2  2002/10/01 08:54:58  egil
+Changed sprintf to snprintf
+
+Revision 1.12.2.1  2001/02/14 06:46:06  egil
+Fixes from Winston Edmond
+
 Revision 1.12  1999/04/08 10:48:51  src
 Extendeddbz to configure
 
@@ -116,6 +122,9 @@ Changed fopen() to fopen_W() to support read/only mode *EK*
 #if HAVE_SYS_TIME_H
 #  include <sys/time.h>
 #endif
+#if HAVE_MEMORY_H
+#  include <memory.h>
+#endif
 
 #include <stdio.h> 
 #include <unistd.h>
@@ -1777,15 +1786,15 @@ void RemoveDBZ(char *filename) {
     char fn[1024];
 
     if (do_tagged_hash) {
-	sprintf(fn, "%s.pag", filename);
+	snprintf(fn,sizeof(fn),"%s.pag", filename);
 	unlink(fn);
     } else {
-	sprintf(fn, "%s.exists", filename);
+	snprintf(fn,sizeof(fn),"%s.exists", filename);
 	unlink(fn);
-	sprintf(fn, "%s.index", filename);
+	snprintf(fn,sizeof(fn),"%s.index", filename);
 	unlink(fn);
     }
-    sprintf(fn, "%s.dir", filename);
+    snprintf(fn,sizeof(fn),"%s.dir", filename);
     unlink(fn);
 }
 
