@@ -1,8 +1,17 @@
-/*  VER 009   TAB P   $Id: dbz.c,v 1.9 1998/09/21 10:33:32 src Exp $
+/*  VER 013   TAB P   $Id: dbz.c,v 1.12 1999/03/05 11:20:33 src Exp $
  *
- *  include appropriate dbz version
+ *  dbz version 6
  *
  *  $Log: dbz.c,v $
+ *  Revision 1.12  1999/03/05 11:20:33  src
+ *  Delayed decision of dbz v3 vz. 6 to runtime.
+ *
+ *  Revision 1.11  1999/03/04 17:18:36  src
+ *  Split between dbz v3 and v6 improved
+ *
+ *  Revision 1.10  1999/03/04 16:19:48  src
+ *  Renamed dbz v3, and introduced DBZ_READONLY
+ *
  *  Revision 1.9  1998/09/21 10:33:32  src
  *  Getting rid of some warnings.
  *
@@ -22,11 +31,11 @@
 #include "common.h"
 
 /*
- *  use dbz in read/only mode
+ *  use dbz v6 in read/only mode
  */
-#define DBZ_READONLY
+#define DBZ_READONLY 1
 
-#ifdef DBZ_READONLY /*EK*/
+#if DBZ_READONLY /*EK*/
 #  define fopen_W(n,m) NULL
 #else
 #  define fopen_W(n,m) fopen(n,m)
@@ -54,18 +63,8 @@ debug_dbz();
 /* debug_dbz(char *fmt, char *arg1,char *arg2,char *arg3,char *arg4); */
 #endif
 
-#if DBZ_VERSION==6
-
 /*
  *  v6
  */
 #include "dbz-v6.c"
 
-#else
-
-/* 
- *  v3
- */
-#include "dbz-v3.c"
-
-#endif
