@@ -1,4 +1,4 @@
-/* $Id: hash.c,v 1.7 1999/03/05 11:20:34 src Exp $
+/* $Id: hash.c,v 1.7.2.1 2001/02/14 06:46:06 egil Exp $
 
    This provides a generic hash function for use w/INN.  Currently
    is implemented using MD5, but should probably have a mechanism for
@@ -8,6 +8,9 @@
    for dbz version 6
 
    $Log: hash.c,v $
+   Revision 1.7.2.1  2001/02/14 06:46:06  egil
+   Fixes from Winston Edmond
+
    Revision 1.7  1999/03/05 11:20:34  src
    Delayed decision of dbz v3 vz. 6 to runtime.
 
@@ -23,10 +26,15 @@
    Revision 1.3  1998/07/12 09:39:19  src
    NewsX version 1.0
 */
+#include "configdata.h"
+
+#if HAVE_MEMORY_H
+#  include <memory.h>
+#endif
+
 #include <stdio.h>
 #include <sys/types.h>
 #include <ctype.h>
-#include "configdata.h"
 
 #include "clibrary.h"
 #include "libinn.h"
