@@ -1,8 +1,11 @@
-/*  $Id: libinn.h,v 1.5 1998/09/21 10:33:32 src Exp $
+/*  $Id: libinn.h,v 1.6 1999/04/08 10:48:52 src Exp $
  *
  *  extracted from INN version 2.0
  *
  *  $Log: libinn.h,v $
+ *  Revision 1.6  1999/04/08 10:48:52  src
+ *  Extendeddbz to configure
+ *
  *  Revision 1.5  1998/09/21 10:33:32  src
  *  Getting rid of some warnings.
  *
@@ -26,13 +29,6 @@ HASH HashMessageID(const char *MessageID);
 /* Convert hash to a form that we can use in error messages */
 char *HashToText(const HASH hash);
 
-struct conf_vars {
-	int extendeddbz;        /* NOTE: all that is required for dbz */
-	int storageapi;
-} ;
-extern struct   conf_vars *innconf;
-
 /*EK*/
 int SetNonBlocking(int fd, BOOL flag);
-int ReadInnConf(void);
 #endif
