@@ -1,19 +1,22 @@
-/*  $Id: macros.h,v 1.3 1998/07/12 09:39:19 src Exp $
+/*  $Id: macros.h,v 1.3.2.1 2002/01/29 06:44:45 egil Exp $
  *
  *  extracted from INN version 2.0
  *
  *  $Log: macros.h,v $
+ *  Revision 1.3.2.1  2002/01/29 06:44:45  egil
+ *  Changing from xmalloc, xrealloc, xstrcpy to
+ *  malloc_perfect, realloc_perfect and strdup_perfect
+ *
  *  Revision 1.3  1998/07/12 09:39:19  src
  *  NewsX version 1.0
- *
  */
 
 #ifndef _MACROS_H
 #define _MACROS_H
 
 #if !defined(NEW)
-#define NEW(T, c)     ((T *)xmalloc((unsigned int)(sizeof (T) * (c))))
-#define RENEW(p,T, c) ((T *)xrealloc((void *)p,(unsigned int)(sizeof (T) * (c))))
+#define NEW(T, c)     ((T *)malloc_perfect((unsigned int)(sizeof (T) * (c))))
+#define RENEW(p,T, c) ((T *)realloc_perfect((void *)p,(unsigned int)(sizeof (T) * (c))))
 #define DISPOSE(p)    (free((void *)p))
 
 #define ISWHITE(c)             ((c) == ' ' || (c) == '\t')
