@@ -1,8 +1,11 @@
-/*  VER 003  TAB P  $Id: dummy.c,v 1.1 1999/03/11 08:00:27 src Exp $
+/*  VER 006  TAB P  $Id: dummy.c,v 1.1.2.1 2003/01/21 09:43:48 egil Exp $
  *
  *  dummies for some functions in libstorage provides
  *
  *  $Log: dummy.c,v $
+ *  Revision 1.1.2.1  2003/01/21 09:43:48  egil
+ *  Updated dummy to do SMerrno
+ *
  *  Revision 1.1  1999/03/11 08:00:27  src
  *  Moved from storage
  *
@@ -16,6 +19,7 @@
 /*
  *  error reporting
  */
+int SMerrno = SMERR_NOERROR;
 char *SMerrorstr;
 
 /*
@@ -55,6 +59,7 @@ BOOL
 SMinit(void)
 {
     SMerrorstr = "Storage-API not available";
+    SMerrno = SMERR_UNINIT;
     return FALSE;
 }
 
