@@ -1,9 +1,12 @@
-/*  VER 004  TAB P  $Id: dummy.h,v 1.2 1999/04/05 19:01:49 src Exp $
+/*  VER 005  TAB P  $Id: dummy.h,v 1.2.2.1 2003/01/21 09:43:48 egil Exp $
  *
  *  dummy storage-API
  *  used in case nothing is available from INN
  *
  *  $Log: dummy.h,v $
+ *  Revision 1.2.2.1  2003/01/21 09:43:48  egil
+ *  Updated dummy to do SMerrno
+ *
  *  Revision 1.2  1999/04/05 19:01:49  src
  *  Lock for scanlogs
  *
@@ -35,6 +38,10 @@ typedef struct {
     time_t arrived;             /* when article arrived */
 } ARTHANDLE;
 
+#define SMERR_NOERROR      0
+#define SMERR_NOENT        3
+#define SMERR_UNINIT       6
+extern int SMerrno;
 extern char *SMerrorstr;
 
 BOOL IsToken(const char *text);
