@@ -1,4 +1,4 @@
-/*  VER 050   TAB P   $Id: auth.c,v 1.16 1998/09/14 05:41:04 src Exp $
+/*  VER 054   TAB P   $Id: auth.c,v 1.16.2.4 2002/10/01 08:54:58 egil Exp $
  *
  *  authorization related stuff
  *
@@ -6,6 +6,21 @@
  *  the GNU General Public License applies
  *
  *  $Log: auth.c,v $
+ *  Revision 1.16.2.4  2002/10/01 08:54:58  egil
+ *  Changed sprintf to snprintf
+ *
+ *  Revision 1.16.2.3  2002/09/21 17:20:35  egil
+ *  A long range of patches incorporated..
+ *
+ *  Revision 1.16.2.2  2002/02/06 20:38:19  egil
+ *
+ *  Debian Bug#26209:
+ *  Really done earlier...
+ *
+ *  Revision 1.16.2.1  2002/01/29 06:44:48  egil
+ *  Changing from xmalloc, xrealloc, xstrcpy to
+ *  malloc_perfect, realloc_perfect and strdup_perfect
+ *
  *  Revision 1.16  1998/09/14 05:41:04  src
  *  Added setenv.h
  *
@@ -107,15 +122,16 @@ do_authinfo_generic(char *username)
 
     fdsenv = getenv("NNTP_AUTH_FDS");
     if (!fdsenv || sscanf(fdsenv, "%*u.%*u.%u",&cookie) != 1) {
-	 tfile = tmpfile();
-	 if (!tfile) {
+	tfile = tmpfile();
+	if (!tfile) {
 	    log_msg(L_ERRno,"cannot create temp file");
 	    unlock_exit(1);
-	 }
-	 cookie = fileno(tfile);
+	}
+	cookie = fileno(tfile);
     }
 
-    /* We set NNTP_AUTH_FDS to let the child process know which
+    /*
+     * We set NNTP_AUTH_FDS to let the child process know which
      * file descriptors to use to read and write to the news server.
      * If the no-action flag was set then sock->r_str and sock->w_str
      * will be zero, so don't try either setting NNTP_AUTH_FDS or
@@ -124,27 +140,27 @@ do_authinfo_generic(char *username)
     if (!noaction_opt) {
 	char env[1024];
 #ifdef HAVE_PUTENV
-	sprintf(env,"NNTP_AUTH_FDS=%d.%d.%d",
+	snprintf(env,sizeof(env),"NNTP_AUTH_FDS=%d.%d.%d",
 	       fileno(sock->r_str),fileno(sock->w_str),cookie);
-	putenv(xstrcpy(env));
+	putenv(strdup_perfect(env));
 	/* suspect that some putenv's might need an allocated value */
 #else
-	 sprintf(env,"%d.%d.%d",
+	snprintf(env,sizeof(env),"%d.%d.%d",
 	       fileno(sock->r_str),fileno(sock->w_str),cookie);
-	 setenv("NNTP_AUTH_FDS",env,1);
+	setenv("NNTP_AUTH_FDS",env,1);
 #endif
     }
 
-    sprintf(buf,"AUTHINFO GENERIC %.990s%s", username, newline);
-    put_server(buf);
+    snprintf(buf,sizeof(buf),"AUTHINFO GENERIC %.990s", username);
+    put_server_cmd(buf);
     /* forking the new process is a fact worth noting... */
     log_msg(L_INFO, "spawning authinfo generic process: %s",username);
     progtitle("spawning authinfo generic process");
     if (!noaction_opt) {
-       if (system(username)) {
-	  log_msg(L_ERR,"authentication failed");
-	  unlock_exit(4);
-       }
+	if (system(username)) {
+	    log_msg(L_ERR,"authentication failed");
+	    unlock_exit(4);
+	}
     }
     /* if we got this far we successfully authenticated ourselves */
 }
@@ -158,9 +174,10 @@ do_authinfo_user(char *username,char *password)
     char buf[NNTP_STRLEN];
     char *endptr;
 
+    /* no, use AUTHINFO USER */
     /* send the username to the server */
-    sprintf(buf, "AUTHINFO USER %s%s", username,newline);
-    if (!put_server(buf)) exit_cleanup(9);
+    snprintf(buf,sizeof(buf),"AUTHINFO USER %s", username);
+    if (!put_server_cmd(buf)) exit_cleanup(9);
     if (noaction_opt) return;
 
     /* get the response and check it's okay */
@@ -169,14 +186,14 @@ do_authinfo_user(char *username,char *password)
 	log_msg(L_ERR,"NNTP authinfo protocol error: got \"%s\"", buf);
 	exit_cleanup(4);
     }
-			
-    /* send the password to the server, 
+
+    /* send the password to the server,
        avoiding announcing password too loudly */
-    sprintf(buf, "AUTHINFO PASS *%s", newline);
-    log_msg(L_PUT,"%s", buf);
-    sprintf(buf, "AUTHINFO PASS %s%s", password,newline);
+    log_msg(L_PUT,"AUTHINFO PASS *\n", buf);
+    snprintf(buf,sizeof(buf),"AUTHINFO PASS %s", password);
     if (!put_server_nolog(buf)) exit_cleanup(9);
-    memset(buf,0,sizeof(buf));
+    memset(buf,0,sizeof(buf)); /* don't let password show for too long */
+    /* BUG: what about password[] */
 
     /* get the response and check it's okay */
     if (!get_server_nntp(buf, sizeof(buf))) {
@@ -213,8 +230,7 @@ do_mode_reader(void)
 
     progtitle("mode reader");
     /* send the command to the server */
-    sprintf(buf, "MODE READER%s", newline);
-    if (!put_server(buf)) exit_cleanup(9);
+    if (!put_server_cmd("MODE READER")) exit_cleanup(9);
     if (noaction_opt) return;
 
     /* get the response and check it's okay */
