@@ -1,4 +1,4 @@
-/*  VER 119  TAB P   $Id: common.h,v 1.9 1998/09/21 10:04:29 src Exp $
+/*  VER 131  TAB P   $Id: common.h,v 1.17.2.3 2003/05/18 10:57:24 egil Exp $
  *
  *  common header file
  *
@@ -6,6 +6,39 @@
  *  the GNU General Public License applies
  *
  *  $Log: common.h,v $
+ *  Revision 1.17.2.3  2003/05/18 10:57:24  egil
+ *  Version 1.6, with fixes from bug #237
+ *
+ *  Revision 1.17.2.2  2003/01/22 13:01:13  egil
+ *  Support sys/malloc.h as used by Mac OS X.
+ *
+ *  Revision 1.17.2.1  2003/01/21 09:47:24  egil
+ *  Renamed MAXHEADERSIZE to MAX_HEADER_SIZE due to name collision
+ *
+ *  Revision 1.17  1999/04/17 07:11:26  src
+ *  malloc.h inclusion
+ *
+ *  Revision 1.16  1999/04/09 03:59:20  src
+ *  NeXT detail
+ *
+ *  Revision 1.15  1999/03/31 03:38:28  src
+ *  Moved errno.h to common.h
+ *
+ *  Revision 1.14  1999/03/30 05:30:31  src
+ *  Added ifdef NeXT
+ *
+ *  Revision 1.13  1999/03/24 03:52:57  src
+ *  Implemented "newsx" as magic exclude pattern
+ *
+ *  Revision 1.12  1999/03/11 07:30:00  src
+ *  Implemented check for spool free space
+ *
+ *  Revision 1.11  1999/03/07 15:40:58  src
+ *  Removed DBZ_VERSION from configuration
+ *
+ *  Revision 1.10  1999/03/05 11:20:40  src
+ *  Delayed decision of dbz v3 vz. 6 to runtime.
+ *
  *  Revision 1.9  1998/09/21 10:04:29  src
  *  Added new command line options for --inews
  *
@@ -23,7 +56,7 @@
 #define _COMMON_H
 
 #if HAVE_CONFIG_H
-#include "../config.h"
+#  include "../config.h"
 #endif
 
 #include "tune.h"
@@ -32,6 +65,7 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <ctype.h>
+#include <errno.h>
 
 #if STDC_HEADERS
 #  include <stdlib.h>
@@ -41,7 +75,7 @@
 #    include <stdlib.h>
 #  endif
 #  if HAVE_MALLOC_H
-#    include <string.h>
+#    include <malloc.h>
 #  endif
 #  if HAVE_STRING_H
 #    include <string.h>
@@ -52,6 +86,10 @@
 #  endif
 #endif
 
+#if HAVE_SYS_MALLOC_H /* for Mac OS X */
+#  include <sys/malloc.h>
+#endif
+
 #if HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
@@ -71,13 +109,22 @@
 #  endif
 #endif
 
-#include <math.h> /* to get errno defined on NeXT */
-
 /*
- *  not all versions define these..
+ *  NeXT peculiarities
+ *  could have included these from "libc.h", but that creates its
+ *  own set of problems since it is without _POSIX_SOURCE defined
+ */
+#ifdef NeXT
+#   include <math.h> /* to get errno defined on NeXT */
+    extern int gethostname(char *, int);
+    extern char *mktemp(char *);
+#endif
+
+/* 
+ * not all versions define these..
  */
 #ifndef PATH_MAX
-#define PATH_MAX 1024
+#  define PATH_MAX 1024
 #endif
 
 #ifndef __STDC__
@@ -97,12 +144,13 @@ char *spoolname;                /* outgoing spool */
 char *hostport;                 /* port for NNTP server */
 char *pname;                    /* this program */
 char *spooldir;                 /* news spool */
-#define NNTP_PORT "nntp"
+#define NNTP_PORT_NAME "nntp"
 
 /* 
  *  misc status
  */
 int post_allowed;
+int newsx_path;                 /* "newsx" exclude specified */
 
 /*
  *  for rnews and inews
