@@ -1,4 +1,4 @@
-/*  VER 078  TAB P   $Id: despool.c,v 1.9 1998/09/11 16:37:43 src Exp $
+/*  VER 082  TAB P   $Id: despool.c,v 1.13 1999/04/07 08:02:11 src Exp $
  *
  *  do the posting 
  *
@@ -6,6 +6,18 @@
  *  the GNU General Public License applies
  *
  *  $Log: despool.c,v $
+ *  Revision 1.13  1999/04/07 08:02:11  src
+ *  Implemented --profile
+ *
+ *  Revision 1.12  1999/03/16 08:03:29  src
+ *  Renamed lock() to do_lock()
+ *
+ *  Revision 1.11  1999/03/07 14:58:18  src
+ *  Read newsconfig supported. Storage API supported.
+ *
+ *  Revision 1.10  1998/11/22 08:00:07  src
+ *  Option --no-queue
+ *
  *  Revision 1.9  1998/09/11 16:37:43  src
  *  Lockfile for logfile of posted articles and for posted article folder.
  *
@@ -23,6 +35,7 @@
 #include "proto.h"
 #include "options.h"
 #include "news.h"
+#include "newsconfig.h"
 #include "stat.h"
 
 /* 
@@ -51,13 +64,10 @@ despool_line(void)
     struct stat st;
 
     if (!togofp) {
-	char batchdir[PATH_MAX];
-
 	progtitle("locking outgoing spool");
 
 	/* file not open yet: prepare names */
-	build_alt_filename(batchdir,SPOOL,BATCH,batch);
-	build_alt_filename(basicname,batchdir,spoolname,NULL);
+	build_alt_filename(basicname,cfg_batch,spoolname,NULL);
 
 	if (inn_opt) {
 	    /* 
@@ -85,7 +95,7 @@ despool_line(void)
 	    char lockname[PATH_MAX];
 
 	    build_filename(lockname,I_LOCK,spoolname,NULL,NULL);
-	    lock(NULL,lockname);
+	    do_lock(NULL,lockname,0);
 
 	    /* prepare the names we will be using */
 	    /* BUG: spoolname.togo */
@@ -102,7 +112,7 @@ despool_line(void)
 	    }
 
 	    /* verify that it is a regular file */
-	    if (!is_regular(togofp,basicname)) {
+	    if (!is_regular(togofp,basicname,NULL)) {
 		/* NOTE: will usually mean we use INN flag under C News */
 		if (S_ISDIR(st.st_mode)) {
 		    /* see if probable C News spool */
@@ -157,7 +167,7 @@ despool_line(void)
 	     */
 
 	    /* lock file first */
-	    lock(basicname,C_LOCK);
+	    do_lock(basicname,C_LOCK,0);
 
 	    /* then prepare name of file */
 	    build_alt_filename(togoname,basicname,C_TOGO,togo);
@@ -175,7 +185,7 @@ despool_line(void)
 		exit_cleanup(5);
 	    }
 	    /* verify that it is a regular file */
-	    if (!is_regular(togofp,togoname)) {
+	    if (!is_regular(togofp,togoname,NULL)) {
 		fclose(togofp);
 		exit_cleanup(5);
 	    }
