@@ -1,4 +1,4 @@
-/*  VER 228   TAB P   $Id: getarticle.c,v 1.26 1999/04/18 09:28:45 src Exp $
+/*  VER 235   TAB P   $Id: getarticle.c,v 1.26.2.6 2003/01/21 09:47:25 egil Exp $
  *
  *  fetch articles via an NNTP server
  *
@@ -10,6 +10,24 @@
  *  the GNU General Public License applies
  *
  *  $Log: getarticle.c,v $
+ *  Revision 1.26.2.6  2003/01/21 09:47:25  egil
+ *  Renamed MAXHEADERSIZE to MAX_HEADER_SIZE due to name collision
+ *
+ *  Revision 1.26.2.5  2002/10/01 08:54:59  egil
+ *  Changed sprintf to snprintf
+ *
+ *  Revision 1.26.2.4  2002/09/21 17:36:32  egil
+ *  Bug #82: Incorrect quoting of leading periods
+ *
+ *  Revision 1.26.2.3  2002/09/21 17:20:35  egil
+ *  A long range of patches incorporated..
+ *
+ *  Revision 1.26.2.2  2002/02/06 18:36:42  egil
+ *  Fix for Debian Bug#123119
+ *
+ *  Revision 1.26.2.1  2001/02/14 06:47:31  egil
+ *  Compiler warning
+ *
  *  Revision 1.26  1999/04/18 09:28:45  src
  *  Fix for --tag with --no-path
  *
@@ -104,33 +122,34 @@ static int
 is_fake(char *msgid)
 {
     while (*msgid && isspace(*msgid)) ++msgid;
-    return is_tag(msgid,"<fake@");
+    return is_tag_n(msgid,strlen(msgid),"<fake@");
 }
 
 /*
  *  read an article proper
- *  and feed it to the spool
+ *  and feed it to the spool as required
  *  arguments are just for error reports
  *  return false on errors that mean we should not continue
  */
 static int 
 read_article(long where,char *group)
 {
-    char line[MAXHEADERSIZE+1];
-    char path_line[MAXHEADERSIZE+1];
+    char linebuf[MAX_HEADER_SIZE+1], *line;
+    char path_line[MAX_HEADER_SIZE+1];
     int reject = 0;
-    int newline = 1;
+    int is_newline = 1;
     int header = 1;
     int path_ok = -1;
     long len;
     long bytecount = 0L; /* BUG: */
 
-    line[MAXHEADERSIZE] = '\0'; /* better safe than sorry */
+    line=linebuf;
+    line[MAX_HEADER_SIZE] = '\0'; /* better safe than sorry */
     path_line[0] = '\0';
 
     /* fetch the article, header and body */
     for (;;) {
-	if (!get_server_msg(line, MAXHEADERSIZE)) {
+	if (!get_server_msg(line, MAX_HEADER_SIZE)) {
 	    /* timeout: simply give up */
 	    return 0;
 	}
@@ -138,18 +157,29 @@ read_article(long where,char *group)
 	len = strlen(line);
 	gross_bytecount += len;
 
-	/* end of file */
-	if (newline && line[0]=='.' && (line[1]=='\r' || line[1]=='\n')) break;
+	/* line starts with a period */
+	if (is_newline && line[0]=='.') {
+	    if (line[1]=='\r' || line[1]=='\n') {       /* single period, i.e. end of file */
+		break;
+	    } else {
+		if (line[1]=='.') {             /* escape-period, remove it */
+		    line++;
+		    len--;
+		} else { 
+		    /* cannot happen */
+		}
+	    }
+	}
 
 	/* process header part */
-	if (header && newline && len > 0) {
+	if (header && is_newline && len > 0) {
 	    switch (line[0]) {
 	    case '\r':
 	    case '\n':
 		header = 0;
 		break;
 	    case 'M':         /* 12345678901 */
-		if (is_tag(line,"Message-ID:")) {
+		if (is_tag_n(line,strlen(line),"Message-ID:")) {
 		    if (!keep_fake && is_fake(line+11)) {
 			/* Dnews style faked message */
 			reject = 1;
@@ -157,7 +187,7 @@ read_article(long where,char *group)
 		}
 		break;
 	    case 'P':
-		if (is_tag(line,"Path:")) {
+		if (is_tag_n(line,strlen(line),"Path:")) {
 		    char *path = skipsp(line+5);
 		    int add_tag = tag_opt;
 		    /* BUG: what about veeeery long lines - point into buffer instead */
@@ -179,10 +209,9 @@ read_article(long where,char *group)
 		    }
 
 		    if (add_tag) {
-			if (len < MAXHEADERSIZE-(2+strlen(NEWSX_PATH))) {
+			if (len < MAX_HEADER_SIZE-(2+strlen(NEWSX_PATH))) {
 			/* save the day by inserting "magic" path */
-			    sprintf(line,"Path: %s!%s",NEWSX_PATH,
-							path_line);
+			    sprintf(line,"Path: %s!%s", NEWSX_PATH, path_line);
 			    len = strlen(line);
 
 			    log_msg(L_DEBUGMORE,"inserting %s path",
@@ -190,7 +219,7 @@ read_article(long where,char *group)
 			    if (newsx_path) path_ok = 1;
 			} else {
 			    log_msg(L_ERR,
-			    "No room to extend path in ARTICLE %ld, adjust MAXHEADERSIZE",
+			    "No room to extend path in ARTICLE %ld, adjust MAX_HEADER_SIZE",
 								where);
 			    reject = -1;
 			}
@@ -204,14 +233,14 @@ read_article(long where,char *group)
 	}
 
 	/* find and strip newlines */
-	newline = 0;
+	is_newline = 0;
 	while (len > 0 && (line[len-1]=='\r' || line[len-1]=='\n')) {
 	    /* fix by: "J. Richard Sladkey" <jrs@foliage.com> */
-	    if (line[len-1]=='\n') newline=1;
+	    if (line[len-1]=='\n') is_newline=1;
 	    --len;
 	}
 
-	if (bytecount+len+newline > temp_len) {
+	if (bytecount+len+is_newline > temp_len) {
 	     /* there is not enough room */
 	     temp_store = temp_store ? realloc(temp_store,temp_len+TEMP_STEP)
 				     : malloc(TEMP_STEP);
@@ -224,7 +253,7 @@ read_article(long where,char *group)
 
 	if (len > 0) memcpy(temp_store+bytecount,line,len);
 	bytecount += len;
-	if (newline) temp_store[bytecount++] = '\n';
+	if (is_newline) temp_store[bytecount++] = '\n';
     }
 
     /* reject article? */
@@ -233,18 +262,18 @@ read_article(long where,char *group)
 	    log_msg(L_DEBUG,"ARTICLE %ld rejected as fake",where);
 	    ++fake_articles;
 	}
-	return 0;
+	return 1; /* reject, but do continue */
     }
 
     /* get status of filtering */
     if (filter && !reject) {
 	/* get filter status */
 	char id[20];
-	sprintf(id,"%ld",where);
+	snprintf(id,sizeof(id),"%ld",where);
 	if (filter_reject(id)) {
 	    log_msg(L_DEBUG,"ARTICLE %ld rejected by full filter",where);
 	    ++filter_articles;
-	    return 0;
+	    return 1; /* rejected, but do continue */
 	}
     }
 
@@ -262,6 +291,7 @@ read_article(long where,char *group)
 				       where, group);
 	    }
 	}
+	/* we assume this is a generic error, no point in continuing */
 	return 0;
     }
 
@@ -292,7 +322,7 @@ handle_article(char *status, long where, char *group)
 	if (a != where) {
 	    if (a==0 && window <= 1) {
 		/* OK, we'll allow it - presumably a non-conforming server */
-		static told = 0;
+		static int told = 0;
 		if (!told) {
 		    log_msg(L_INFO,"no article number in ARTICLE response: %s",
 								       status);
@@ -305,7 +335,7 @@ handle_article(char *status, long where, char *group)
 	    }
 	}
 	if ((ok = read_article(where,group))) {
-	    /* article is presumably OK */
+	    /* we are still up and running */
 	    latest_where = where;
 
 	    /* show that something is happening */
@@ -339,13 +369,13 @@ current_article(long where,char *group)
     char request[NNTP_STRLEN+1];
 
     if (no_stat) {
-	sprintf(request, " %ld", where);
+	snprintf(request,sizeof(request)," %ld", where);
 	progtitle2(group, request);
     }
 
-    sprintf(request, "ARTICLE %ld%s", where, newline);
+    snprintf(request,sizeof(request),"ARTICLE %ld", where);
     latest_contains_msgnum = 1;
-    return put_request(request,handle_article,where,group);
+    return put_request_c(request,handle_article,where,group);
 }
 
 /*
@@ -460,9 +490,9 @@ handle_next(char *status,long where,char *group)
 	    log_msg(L_ERR,"bad NEXT reponse: %s", status);
 	    /* try to recover in a fashion */
 	    no_next = 1;
-	    sprintf(msgid, "STAT %ld%s", where,newline);
+	    snprintf(msgid,sizeof(msgid),"STAT %ld", where);
 	    latest_contains_msgnum = 1;
-	    return put_request(msgid,handle_stat,where,group);
+	    return put_request_c(msgid,handle_stat,where,group);
 	}
 	latest_next = a;
 	return process_msgid(msgid,a,group);
@@ -516,13 +546,13 @@ fetch_article(long where,int first,char *group)
     }
 
     if (no_stat) {
-	sprintf(status,"%d",99);
+	snprintf(status,sizeof(status),"%d",99);
 	/* fake dummy STAT message that will cause an ARTICLE */
 	return handle_stat(status,where,group);
     }
 
     /* enquire article status and message ID */
-    sprintf(request, " %ld", where);
+    snprintf(request,sizeof(request)," %ld", where);
     progtitle2(group, request);
 
     if (!first && !no_next && stat_failures >= stat_attempts) {
@@ -554,17 +584,16 @@ fetch_article(long where,int first,char *group)
 	    log_msg(L_DEBUGMORE,"before NEXT: stat_failures %d", stat_failures);
 	    goto issue_a_stat;
 	}
-	sprintf(request, "NEXT%s", newline);
 	++next_requests;
 	latest_contains_msgnum = 0;
-	return put_request(request,handle_next,where,group);
+	return put_request_c("NEXT",handle_next,where,group);
     }
 
     /* issue a standard STAT */
   issue_a_stat:
-    sprintf(request, "STAT %ld%s", where,newline);
+    snprintf(request,sizeof(request),"STAT %ld", where);
     latest_contains_msgnum = 1;
-    return put_request(request,handle_stat,where,group);
+    return put_request_c(request,handle_stat,where,group);
 }
 
 /*
@@ -612,9 +641,8 @@ select_group(char *group,long *firstp,long *lastp)
 
     progtitle(group);
 
-    sprintf(request, "GROUP %s%s", group,newline);
-
-    if (!put_server(request)) return -1;
+    snprintf(request,sizeof(request),"GROUP %s", group);
+    if (!put_server_cmd(request)) return -1;
 
     /* get status */
     if (!get_server_nntp(status, sizeof(status))) return -1;
