@@ -1,4 +1,4 @@
-/*  VER 025  TAB P   $Id: list.c,v 1.6 1998/09/09 07:32:12 src Exp $
+/*  VER 030  TAB P   $Id: list.c,v 1.7.2.1 2002/09/21 17:20:35 egil Exp $
  *
  *  fetch the active list
  *
@@ -6,6 +6,12 @@
  *  the GNU General Public License applies
  *
  *  $Log: list.c,v $
+ *  Revision 1.7.2.1  2002/09/21 17:20:35  egil
+ *  A long range of patches incorporated..
+ *
+ *  Revision 1.7  1998/11/21 19:14:23  src
+ *  Added --filter option
+ *
  *  Revision 1.6  1998/09/09 07:32:12  src
  *  Version 1.1
  *
@@ -100,6 +106,7 @@ read_list(FILE *f_all,FILE *f_new, int is_desc)
 			/* pick moderation status too */
 			status = 'y';
 			sscanf(p+1,"%ld %ld %c",&n1,&n2,&status);
+			*p = '\0';
 			if (f_new && !is_in_active(line)) {
 			    report_list(f_new,line,status,group_newlist);
 			}
@@ -121,7 +128,7 @@ read_list(FILE *f_all,FILE *f_new, int is_desc)
  *  return false if no point in continuing
  */
 static int 
-handle_list(char *status, long dummy)
+handle_list(char *status, long dummy, char *group)
 {
     FILE *f_all = 0;
     FILE *f_new = 0;
@@ -156,7 +163,7 @@ handle_list(char *status, long dummy)
  *  fetch description proper
  */
 static int 
-handle_desc(char *status, long dummy)
+handle_desc(char *status, long dummy, char *group)
 {
     FILE *f_all = 0;
     FILE *f_new = 0;
@@ -193,8 +200,6 @@ handle_desc(char *status, long dummy)
 void
 get_list(void)
 {
-    char request[NNTP_STRLEN+1];
-
     if (!group_list && !group_newlist) return;
 
     progtitle("get list");
@@ -202,9 +207,7 @@ get_list(void)
     if (group_list) log_msg(L_DEBUG,"get full list to %s",group_list);
     if (group_newlist) log_msg(L_DEBUG,"get new list to %s",group_newlist);
 
-    sprintf(request, "LIST%s", newline);
-
-    if (!put_request(request,handle_list,0L)) {
+    if (!put_request_c("LIST",handle_list,0L,"")) {
 	exit_cleanup(9);
     }
 }
@@ -215,8 +218,6 @@ get_list(void)
 void
 get_desc(void)
 {
-    char request[NNTP_STRLEN+1];
-
     if (!group_desc && !group_alldesc) return;
 
     progtitle("get desc");
@@ -224,9 +225,7 @@ get_desc(void)
     if (group_desc) log_msg(L_DEBUG,"get descriptions to %s",group_desc);
     if (group_alldesc) log_msg(L_DEBUG,"get all descriptions to %s",group_alldesc);
 
-    sprintf(request, "LIST NEWSGROUPS%s", newline);
-
-    if (!put_request(request,handle_desc,0L)) {
+    if (!put_request_c("LIST NEWSGROUPS",handle_desc,0L,"")) {
 	exit_cleanup(9);
     }
 }
