@@ -1,9 +1,9 @@
-/*  VER 302   TAB P   $Id: main.c,v 1.46 1999/04/25 07:00:37 src Exp $
+/*  VER 315   TAB P   $Id: main.c,v 1.45.2.13 2003/05/18 10:57:25 egil Exp $
  *
  *  an NNTP news exchange client
  *
- *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
- *  Husebybakken 14A, N-0379 Oslo, Norway         
+ *  copyright 1996, 1997, 1998, 2003 Egil Kvaleberg, egil@kvaleberg.no
+ *  Husebybakken 14A, NO-0379 Oslo, Norway
  *
  *  this program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,46 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  $Log: main.c,v $
- *  Revision 1.46  1999/04/25 07:00:37  src
- *  Mellowed error message for missing standard profiles
+ *  Revision 1.45.2.13  2003/05/18 10:57:25  egil
+ *  Version 1.6, with fixes from bug #237
+ *
+ *  Revision 1.45.2.12  2003/01/22 10:18:25  egil
+ *  Implemented hostconfig, removed storageapi
+ *
+ *  Revision 1.45.2.11  2003/01/21 20:19:44  egil
+ *  mktemp() replaced by newstemp()
+ *
+ *  Revision 1.45.2.10  2003/01/21 08:01:08  egil
+ *  Renamed to PACKAGE_ style
+ *
+ *  Revision 1.45.2.9  2003/01/21 07:13:54  egil
+ *  New country code
+ *
+ *  Revision 1.45.2.8  2003/01/21 07:11:20  egil
+ *  New name for BUGCATCHER
+ *
+ *  Revision 1.45.2.7  2002/10/01 08:54:59  egil
+ *  Changed sprintf to snprintf
+ *
+ *  Revision 1.45.2.6  2002/09/30 18:58:38  egil
+ *  Fix for debian bug #65851
+ *
+ *  Revision 1.45.2.5  2002/09/21 17:20:35  egil
+ *  A long range of patches incorporated..
+ *
+ *  Revision 1.45.2.4  2002/02/06 19:54:49  egil
+ *
+ *  Debian Bug#84621: newsq --help
+ *
+ *  Revision 1.45.2.3  2002/01/29 19:40:37  egil
+ *  Spool name with a slash
+ *
+ *  Revision 1.45.2.2  2002/01/29 06:44:48  egil
+ *  Changing from xmalloc, xrealloc, xstrcpy to
+ *  malloc_perfect, realloc_perfect and strdup_perfect
+ *
+ *  Revision 1.45.2.1  2001/02/14 06:55:40  egil
+ *  Fixes from Winston Edmond
  *
  *  Revision 1.45  1999/04/19 04:20:07  src
  *  Profile for specific spool
@@ -141,7 +179,7 @@
 #include "options.h"
 #include "self.h"
 #include "news.h"
-#include "patchlevel.h"
+#include "stat.h"
 
 #define INIT_CONFIG 1
 #include "newsconfig.h"
@@ -152,10 +190,6 @@
 #include "../lib/getopt.h"
 #endif
 
-#if HAVE_SYS_STAT_H
-#  include <sys/stat.h>
-#endif
-
 static void
 load_profile(char *name, char *envp[],int complain);
 static void
@@ -170,6 +204,8 @@ static void
 timearg(char *arg,long *where, char dflt, char option);
 
 char *newline = "\r\n";
+int len_newline = 2;
+
 static int did_stat_attempts = 0;
 
 /*
@@ -259,6 +295,7 @@ static struct option long_options[] = {
     {"spoolname",       1, 0, 27},
     {"hostname",        1, 0, 28},
     {"port",            1, 0, 29},
+    {"hostconfig",      1, 0, 30},
     {"readbeforeauth",  0, &readbeforeauth_opt, 1}, /* do AUTHINFO after MODE READER */
     {"no-path",         0, &nopath_opt,         1},
     {"no-ps",           0, &no_ps,              1},
@@ -299,7 +336,7 @@ main(int argc, char *argv[], char *envp[])
 
     log_open();
 
-    /* some command line defaults */
+    /* plus some command line defaults */
     nopull_opt = 0;
     inn_opt = INN_MODE;
     minspool = MINSPOOL;
@@ -309,7 +346,7 @@ main(int argc, char *argv[], char *envp[])
     max_path = 1;
 
     /* use the default umask for news */
-    umask(NEWSUMASK);
+    umask(INN_NEWSUMASK);
 
     /*
      *  check if runtime configuration is required
@@ -323,7 +360,7 @@ main(int argc, char *argv[], char *envp[])
 
     /*
      *  load the standard profile, if any
-     *  NOTE: debug flags are not active yet...
+     *  NOTE: debug flags are not active now...
      */
     if (cfg_etc[0]) {
 	char name[PATH_MAX];
@@ -336,12 +373,16 @@ main(int argc, char *argv[], char *envp[])
 
     /* defaults */
     if (!hostname || !hostname[0]) hostname = spoolname;
-    if (!hostport || !hostport[0]) hostport = NNTP_PORT;
+    if (!hostport || !hostport[0]) hostport = NNTP_PORT_NAME;
     if (!spoolname) spoolname = getenv("NNTPSERVER");
     if (!spooldir) stringarg(SPOOL,&spooldir,0);
     if (!did_stat_attempts) stat_attempts = (window==0) ? 0:2;
 
-    /* sanity check */
+    /* sanity checks */
+    if (spoolname && strchr(spoolname,'/')) {
+	fprintf(stderr, "spool name cannot contain a '/': %s\n",spoolname);
+	unlock_exit(2);
+    }
     if (!enquire_opt && (!spoolname || !spoolname[0])) {
 	fprintf(stderr, "spool name missing\n");
 	usage();
@@ -352,11 +393,14 @@ main(int argc, char *argv[], char *envp[])
 	char name[PATH_MAX+PATH_MAX];
 
 	/* set the program title for "ps" */
-	sprintf(name,"%s(%s)",pname,spoolname);
+	snprintf(name,sizeof(name),"%s(%s)",pname,spoolname);
 	settitle(name);
 
 	/* load per-host profile */
-	build_filename(name,cfg_inhosts,"/",spoolname,_CONF);
+	if (cfg_hostconfig && cfg_hostconfig[0])
+	    build_filename(name,cfg_hostconfig,"/",spoolname,_CONF);
+	else
+	    build_filename(name,cfg_inhosts,"/",spoolname,_CONF);
 	load_profile(name, envp, 0);
     }
 
@@ -381,6 +425,8 @@ pickargs(int argc,char *argv[],char *envp[])
     int c;
     char *p;
 
+    optind = 0;                 /* tell getopt to reset internal variables */
+
     for (;;) {
 	option_index = -1;
 	c = getopt_long(argc,argv, long_list, long_options, &option_index);
@@ -465,9 +511,9 @@ pickargs(int argc,char *argv[],char *envp[])
 	    stringarg(optarg,&chat_file,c);
 	    break;
 	case 'v':                       /* version */
-	    printf("%s version %s%s\n", pname, VERSION, PATCHLEVEL);
+	    printf("%s version %s\n", pname, PACKAGE_VERSION);
 	    /* keep the lawyers busy */
-	    printf("%s\n", COPYRIGHT);
+	    printf("%s\n", PACKAGE_COPYRIGHT);
 	    printf("This is free software; the GNU General Public License applies.\n");
 	    printf("There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A\n");
 	    printf("PARTICULAR PURPOSE.\n");
@@ -546,7 +592,7 @@ pickargs(int argc,char *argv[],char *envp[])
 	    break;
 	case '?':                       /* help */
 	    usage();
-	    printf("Report bugs to %s\n", BUGCATCHER);
+	    printf("Report bugs to %s\n", PACKAGE_BUGREPORT);
 	    unlock_exit(0); /* that's ok */
 	    break;
 	case 1:                         /* attach */
@@ -581,6 +627,7 @@ pickargs(int argc,char *argv[],char *envp[])
 	    break;
 	case 8:                         /* newline */
 	    newline = "\n";
+	    len_newline = 1;
 	    break;
 	case 10:
 	    /* --authgeneric : authenticate using AUTHINFO GENERIC */
@@ -597,7 +644,7 @@ pickargs(int argc,char *argv[],char *envp[])
 	     * could be clobbered by another getenv() on some non-GNU systems.
 	     * To be safe, we copy it into fresh memory.
 	     */
-	    ai_username = xstrcpy(ai_username);
+	    ai_username = strdup_perfect(ai_username);
 	    /*
 	     * Note that we are generic. We could do this just by noticing
 	     * that for generic the password string will be NULL, but that's
@@ -685,6 +732,9 @@ pickargs(int argc,char *argv[],char *envp[])
 	case 29:                        /* port */
 	    stringarg(optarg,&hostport,c);
 	    break;
+	case 30:                        /* per host configuration */
+	    stringarg(optarg,&cfg_hostconfig,c);
+	    break;
 	case 0:
 	    break;
 		
@@ -768,9 +818,9 @@ namopt(char short_option)
     static char buf[50];
 
     if (option_index >= 0) { /* it was a long option */
-	sprintf(buf,"--%s",long_options[option_index].name);
+	snprintf(buf,sizeof(buf),"--%s",long_options[option_index].name);
     } else {
-	sprintf(buf,"-%c",short_option);
+	snprintf(buf,sizeof(buf),"-%c",short_option);
     }
     return buf;
 }
@@ -791,12 +841,10 @@ lnumarg(char *arg,long *where, char option)
 	return;
     }
 
-#if 0 /* BUG: find other way of doing this */
-    if (*where != 0 && *where != a) {
-	fprintf(stderr,"%s: option %s was \"%d\", respecified as \"%d\"\n",
+    if (debug_opt && *where != 0 && *where != a) {
+	fprintf(stderr,"%s: option %s was \"%ld\", respecified as \"%ld\"\n",
 		     pname, namopt(option), *where,                a);
     }
-#endif
     *where = a;
 }
 
@@ -819,11 +867,12 @@ numarg(char *arg,int *where, char option)
 static void 
 stringarg(char *arg,char **where, char option)
 {
-    if (*where) {
+	/* echo commandline arguments */
+    if (*where && debug_opt) {
 	fprintf(stderr,"%s: option %s was \"%s\", respecified as \"%s\"\n",
 		     pname, namopt(option), *where,                arg);
     }
-    *where = xstrcpy(arg);
+    *where = strdup_perfect(arg);
 }
 
 /*
