@@ -1,4 +1,4 @@
-/*  VER 014   TAB P   $Id: mfilter.c,v 1.7 1999/04/05 19:01:51 src Exp $
+/*  VER 015   TAB P   $Id: mfilter.c,v 1.7.2.1 2002/10/01 08:54:59 egil Exp $
  *
  *  filter based on message ID
  *
@@ -6,6 +6,9 @@
  *  the GNU General Public License applies
  *
  *  $Log: mfilter.c,v $
+ *  Revision 1.7.2.1  2002/10/01 08:54:59  egil
+ *  Changed sprintf to snprintf
+ *
  *  Revision 1.7  1999/04/05 19:01:51  src
  *  Lock for scanlogs
  *
@@ -45,7 +48,7 @@ do_mfilter(char *msgid)
     inf = open("/dev/null",O_RDWR);
     outf = dup(inf);      
     /* BUG: silly... */
-    sprintf(buf, "%1024.1024s \"%512.512s\"",mfilter,msgid);
+    snprintf(buf,sizeof(buf),"%1024.1024s \"%512.512s\"",mfilter,msgid);
     st = script(buf,inf,outf);
     close(inf);
     close(outf);
