@@ -1,4 +1,4 @@
-/*  VER 022  TAB P   $Id: msgid.c,v 1.6 1999/03/07 14:58:18 src Exp $
+/*  VER 022  TAB P   $Id: msgid.c,v 1.6.2.1 2002/01/29 06:44:48 egil Exp $
  *
  *  handle the message IDs
  *  to ensure we don't read a message twice
@@ -7,6 +7,10 @@
  *  the GNU General Public License applies
  *
  *  $Log: msgid.c,v $
+ *  Revision 1.6.2.1  2002/01/29 06:44:48  egil
+ *  Changing from xmalloc, xrealloc, xstrcpy to
+ *  malloc_perfect, realloc_perfect and strdup_perfect
+ *
  *  Revision 1.6  1999/03/07 14:58:18  src
  *  Read newsconfig supported. Storage API supported.
  *
@@ -53,7 +57,7 @@ new_msgid(char *msgid)
 
     /* add to list */
     n = sizeof(MESSAGE_ID) + strlen(msgid);
-    mp = xmalloc(n);
+    mp = malloc_perfect(n);
     strcpy(mp->name,msgid);
     mp->next = messageids[h];
     messageids[h] = mp;
