@@ -1,4 +1,4 @@
-/*  VER 033  TAB P   $Id: newsconfig.h,v 1.4 1999/04/19 03:32:39 src Exp $
+/*  VER 036  TAB P   $Id: newsconfig.h,v 1.4.2.1 2003/01/22 10:18:25 egil Exp $
  *
  *  news configuration
  *
@@ -6,6 +6,9 @@
  *  the GNU General Public License applies
  *
  *  $Log: newsconfig.h,v $
+ *  Revision 1.4.2.1  2003/01/22 10:18:25  egil
+ *  Implemented hostconfig, removed storageapi
+ *
  *  Revision 1.4  1999/04/19 03:32:39  src
  *  Standard profile in $PATHETC/newsx.conf
  *
@@ -37,8 +40,8 @@ char *cfg_incoming  INIT(INCOMING);     /* -I incoming */
 char *cfg_inhosts   INIT(INHOSTS);      /* -K in.hosts */
 char *cfg_newsfeeds INIT(NEWSFEEDS);    /* -N newsfeeds */
 char *cfg_locks     INIT(LOCKS);        /* -P locks */
+char *cfg_hostconfig INIT(HOSTCONFIG);
 
 int cfg_extendeddbz INIT(INN_EXTENDEDDBZ);
-int cfg_storageapi  INIT(INN_STORAGEAPI);
 
 
