@@ -1,4 +1,4 @@
-/*  VER 014   TAB P   $Id: path.c,v 1.3 1999/03/24 03:53:00 src Exp $
+/*  VER 014   TAB P   $Id: path.c,v 1.3.2.2 2002/10/31 11:51:39 egil Exp $
  *
  *  process path stuff
  *
@@ -6,6 +6,13 @@
  *  the GNU General Public License applies
  *
  *  $Log: path.c,v $
+ *  Revision 1.3.2.2  2002/10/31 11:51:39  egil
+ *  Fix for bug #133, bang_paths
+ *
+ *  Revision 1.3.2.1  2002/01/29 06:44:48  egil
+ *  Changing from xmalloc, xrealloc, xstrcpy to
+ *  malloc_perfect, realloc_perfect and strdup_perfect
+ *
  *  Revision 1.3  1999/03/24 03:53:00  src
  *  Implemented "newsx" as magic exclude pattern
  *
@@ -40,9 +47,9 @@ add_exclusion(char *path)
 
     if (PATH_DEBUG) fprintf(stderr,"Add exclusion: %s\n",path);
 
-    e = xmalloc(sizeof(struct ex_s));
+    e = malloc_perfect(sizeof(struct ex_s));
     e->e_next = exclusion;
-    e->e_name = xstrcpy(path);
+    e->e_name = strdup_perfect(path);
     exclusion = e;
 }
 
@@ -90,12 +97,14 @@ path_match(char *path)
  *  returns the number of exclamation marks
  */
 int
-path_bangs(char *path)
+path_bangs(char *path,int len)
 {
+    char *p = path;
     int bangs = 0;
-    while ((path = strchr(path,'!'))) {
+    while (p < path+len
+	&& (p = memchr(p,'!',(path+len) - p))) {
 	++bangs;
-	++path;
+	++p;
     }
     return bangs;
 }
