@@ -1,4 +1,4 @@
-/*  VER 193   TAB P   $Id: putarticle.c,v 1.23 1999/04/05 19:01:51 src Exp $
+/*  VER 218   TAB P   $Id: putarticle.c,v 1.23.2.19 2003/05/18 10:44:37 egil Exp $
  *
  *  POST articles via an NNTP server
  *
@@ -6,11 +6,68 @@
  *  the GNU General Public License applies
  *
  *  $Log: putarticle.c,v $
+ *  Revision 1.23.2.19  2003/05/18 10:44:37  egil
+ *  Fix for bug #237
+ *
+ *  Revision 1.23.2.18  2003/01/22 10:18:25  egil
+ *  Implemented hostconfig, removed storageapi
+ *
+ *  Revision 1.23.2.17  2003/01/21 09:47:25  egil
+ *  Renamed MAXHEADERSIZE to MAX_HEADER_SIZE due to name collision
+ *
+ *  Revision 1.23.2.16  2002/10/31 11:51:39  egil
+ *  Fix for bug #133, bang_paths
+ *
+ *  Revision 1.23.2.15  2002/10/02 10:08:29  egil
+ *  New filter for SMretrieve
+ *
+ *  Revision 1.23.2.14  2002/10/02 09:05:28  egil
+ *  Do not flush stream when posting
+ *
+ *  Revision 1.23.2.13  2002/10/01 13:09:11  egil
+ *  Silly mistakes
+ *
+ *  Revision 1.23.2.12  2002/10/01 13:07:18  egil
+ *  Silly bug: Omits empty lines!
+ *
+ *  Revision 1.23.2.11  2002/10/01 12:54:35  egil
+ *  Fix for bug #86
+ *
+ *  Revision 1.23.2.10  2002/10/01 09:21:54  egil
+ *  Made function for storage API
+ *
+ *  Revision 1.23.2.9  2002/10/01 08:54:59  egil
+ *  Changed sprintf to snprintf
+ *
+ *  Revision 1.23.2.8  2002/09/21 17:20:35  egil
+ *  A long range of patches incorporated..
+ *
+ *  Revision 1.23.2.7  2002/02/06 20:11:35  egil
+ *  Debian Bug#88795: newsx: Inn 2.3.1 storage API compilation
+ *
+ *  Revision 1.23.2.6  2002/01/29 21:10:16  egil
+ *  More sane handling of articles with CR
+ *
+ *  Revision 1.23.2.5  2002/01/29 20:46:49  egil
+ *  Better error message
+ *
+ *  Revision 1.23.2.4  2002/01/29 20:43:35  egil
+ *  Fixed problems with articles with wrong CRs
+ *
+ *  Revision 1.23.2.3  2002/01/29 07:46:39  egil
+ *  Initialize storage earlier
+ *
+ *  Revision 1.23.2.2  2002/01/29 07:39:03  egil
+ *  Storage API detection fixed
+ *
+ *  Revision 1.23.2.1  2001/02/14 06:55:40  egil
+ *  Fixes from Winston Edmond
+ *
  *  Revision 1.23  1999/04/05 19:01:51  src
  *  Lock for scanlogs
  *
  *  Revision 1.22  1999/04/05 13:07:34  src
- *  Various fixes for storeage-API
+ *  Various fixes for storage-API
  *
  *  Revision 1.21  1999/03/31 03:28:20  src
  *  Also removing "NNTP-Posting-Date" when posting
@@ -85,31 +142,17 @@ static int article_lines = 0;
 
 static int SM_open = 0;
 
-#ifndef HAVE_STRTOUL
-/*
- *  for systems that doesn't have it, assuming base<=10
- */
-long 
-strtoul(char *str,char **endptr,int base)
-{
-    long u = 0L;
-    char c;
-    while (isspace(*str)) ++str;
-    while (isdigit(c = *str++)) u = u*base + c-'0';
-    *endptr = str;
-    return u;
-}
-#endif
-	
 /*
  *  check if header tag
  */
 int
-is_tag(char *line, char *tag)
+is_tag_n(char *line, int len, char *tag)
 {
     char c,d;
+    char *end = line+len;
 
     while ((c = *tag++)) {
+	if (line >= end) return 0;
 	d = *line++;
 	if (toupper(c) != toupper(d)) return 0;
     }
@@ -131,31 +174,32 @@ current_time(void)
 
 /*
  *  check out header...
+ *  cr/lf is not included
  *  update skip state
  */
 static void 
-check_header(char *line, int *skip)
+check_header(char *line, int len, int *skip)
 {
     char *p;
 
-    switch (toupper(line[0])) {
+    if (len > 0) switch (toupper(line[0])) {
 #if 0
     case 'C':
-	if (is_tag(line,p="Content-Type: ")) {
+	if (is_tag_n(line,len,p="Content-Type: ")) {
 	    if (!contenttype[0])
 		strncpy(contenttype,line+strlen(p),sizeof(contenttype)-1);
 	}
 	break;
 #endif
     case 'F':
-	if (is_tag(line,p="From: ")) {
+	if (is_tag_n(line,len,p="From: ")) {
 	    /* use From: if no Sender: */
 	    if (!msgsender[0])
 		strncpy(msgsender,line+strlen(p),sizeof(msgsender)-1);
 	}
 	break;
     case 'M':
-	if (is_tag(line,p="Message-ID: ")) {
+	if (is_tag_n(line,len,p="Message-ID: ")) {
 	    /* record local Message-ID */
 	    strncpy(msgid,line+strlen(p),sizeof(msgid)-1);
 	    if (nomsgid_opt && !ihave_opt) {
@@ -166,8 +210,8 @@ check_header(char *line, int *skip)
 	}
 	break;
     case 'N':
-	if ((is_tag(line,"NNTP-Posting-Host:")
-	  || is_tag(line,"NNTP-Posting-Date:")) && !ihave_opt) {
+	if ((is_tag_n(line,len,"NNTP-Posting-Host:")
+	  || is_tag_n(line,len,"NNTP-Posting-Date:")) && !ihave_opt) {
 	    /*
 	     * when POSTing, these headers may cause
 	     * messages to be rejected
@@ -179,8 +223,9 @@ check_header(char *line, int *skip)
 	}
 	break;
     case 'P':
-	if (is_tag(line,"Path:")) {
-	    int bangs = path_bangs(line+5);
+	if (is_tag_n(line,len,"Path:")) {
+	    /* skip "Path: " */
+	    int bangs = path_bangs(line+6,len-6);
 
 	    if (bangs > max_path) {
 		/* BUG: do something better */
@@ -201,25 +246,25 @@ check_header(char *line, int *skip)
 	}
 	break;
     case 'R':
-	if (is_tag(line,p="Reply-to: ")) {
+	if (is_tag_n(line,len,p="Reply-to: ")) {
 	    /* record Reply-to: */
 	    strncpy(msgsender,line+strlen(p),sizeof(msgsender)-1);
 	}
 	break;
     case 'S':
-	if (is_tag(line,p="Sender: ")) {
+	if (is_tag_n(line,len,p="Sender: ")) {
 	    /* BUG: use Sender if no Reply-to */
 	    strncpy(msgsender,line+strlen(p),sizeof(msgsender)-1);
 	}
 	break;
     case 'X':
-	if (is_tag(line,"Xref:")) {
+	if (is_tag_n(line,len,"Xref:")) {
 	    /* always omit local Xref */
 	    *skip = 1;
 	    return;
-	} else if (is_tag(line,"X-Server-Date:")
-		|| is_tag(line,"X-Trace:")
-		|| is_tag(line,"X-Complaints-To:")) {
+	} else if (is_tag_n(line,len,"X-Server-Date:")
+		|| is_tag_n(line,len,"X-Trace:")
+		|| is_tag_n(line,len,"X-Complaints-To:")) {
 	    if (!ihave_opt) {
 		/* should not occur in postings */
 		*skip = 1;
@@ -238,40 +283,51 @@ check_header(char *line, int *skip)
 }
 
 /*
- *  sniff an article to find its message ID
+ *  sniff an article to see if it is ok
+ *  return false and return reason if problems
+ *  set pointer to message ID if available
  */
-static char *
-sniff_article(ARTHANDLE *article)
+static int
+sniff_article(ARTHANDLE *article,char **id_p,char **reason)
 {
     char *line = article->data;
-    int len;
+    char *end = line + article->len;
+    int linelen;
     int dummy;
+    int hdr = 1;
     char *p;
-    char c;
 
     msgid[0] = '\0';
+    msgsender[0] = '\0';
 	
     /* read the article, header and body */
     progtitle("find message-ID");
-    for (;;) {
-	/* BUG: article->len */
-	if (!(p = strchr(line,'\r')) || p[1]!='\n') {
-	    /* should not happen */
+    while (line < end) {
+	if (!(p = memchr(line,'\r',end-line)) || p+1 >= end || p[1]!='\n') {
+	    *reason = "inconsistent line termination";
+	    log_msg(L_ERR,*reason);
+	    /* article no good */
+	    return 0;
+	}
+	linelen = (p+2) - line;
+
+	if (linelen == 1+2 && line[0] == '.') {
+	    /* proper end-of-file */
 	    break;
 	}
-	len = (p+2) - line;
 
-	if (len == 2) break; /* empty line: end of header */
+	if (linelen == 2) { /* empty line: end of header */
+	    hdr = 0;
+	} else if (hdr) {
+	    check_header(line, p-line, &dummy);
+	}
 
-	c = *p;
-	*p = '\0';
-	check_header(line, &dummy);
-	*p = c;
-	if (msgid[0]) break; /* found header */
-
-	line += len;
+	line += linelen;
     }
-    return msgid[0] ? msgid : 0;
+    if (id_p) {
+	*id_p = msgid[0] ? msgid : 0;
+    }
+    return 1;
 }
 
 /*
@@ -282,12 +338,12 @@ static void
 write_article(ARTHANDLE *article)
 {
     char *line = article->data;
-    int len;
+    char *end = line + article->len;
+    int linelen;
     int hdr = 1;
     int skiphdr = 0;
     FILE *folder_file = 0;
     int lock_id = -1;
-    char c0,c1,c2;
     char *p;
 
     msgid[0] = '\0';
@@ -296,40 +352,32 @@ write_article(ARTHANDLE *article)
 
     /* transfer the article, header and body */
     progtitle("post: transfer article");
-    for (;;) {
-	/* BUG: API what about length? */
-	if (!(p = strchr(line,'\r')) || p[1]!='\n') {
-	    /* panic */
-	    log_msg(L_ERR,"inconsistent article format");
+    while (line < end) {
+	if (!(p = memchr(line,'\r',end-line)) || p+1 >= end || p[1]!='\n') {
+	    /* should not happen: see sniff_article() */
+	    log_msg(L_ERR,"internal article inconsistency");
 	    exit_cleanup(1);
 	}
 
-	len = (p+2) - line;
+	linelen = (p+2) - line;
 	++article_lines;
 
-	if (len == 1+2 && line[0] == '.') {
+	if (linelen == 1+2 && line[0] == '.') {
 	    /* proper end-of-file */
+	    /* BUG: verify with end */
 	    break;
 	}
 
-	if (len == 2) {
+	if (linelen == 2) {
 	    /* empty line: end of header */
 	    hdr = skiphdr = 0;
 	} else if (hdr) {
 	    /* update skip state */
-	    /* BUG: API dirty? */
-	    c0 = *p;
-	    *p = '\0';
-	    check_header(line, &skiphdr);
-	    *p = c0;
+	    check_header(line, p-line, &skiphdr);
 	}
 
 	if (!skiphdr) {
-	    /* BUG: API dirty? */
-	    c0 = *p; c1 = *(p+1); c2 = *(p+2);
-	    strcpy(p,newline);
-	    if (!put_server_msg(line)) exit_cleanup(9);
-	    *p = c0; *(p+1) = c1; *(p+2) = c2;
+	    if (!put_server_line(line,p-line,0)) exit_cleanup(9);
 
 	    /* save to folder also */
 	    if (folder) {
@@ -358,18 +406,14 @@ write_article(ARTHANDLE *article)
 			/* mail folder hack */
 			fputc('>', folder_file);
 		    }
-		    /* BUG: API dirty? */
-		    /* back to Unix convention */
-		    c0 = *p; c1 = *(p+1);
-		    *p = '\n';
-		    *(p+1) = '\0';
-		    fputs(line, folder_file);
-		    *p = c0; *(p+1) = c1;
+		    /* newline to Unix convention */
+		    fwrite(line, sizeof(char), p-line, folder_file);
+		    fputc('\n', folder_file);
 		}
 	    }
-	    net_bytecount += len;
+	    net_bytecount += linelen;
 	}
-	line += len;
+	line += linelen;
     }
 
     if (folder_file) {
@@ -390,8 +434,7 @@ write_article(ARTHANDLE *article)
 
     /* send termination */
     progtitle("post: send termination");
-    sprintf(line, ".%s", newline);
-    if (!put_server_msg(line)) exit_cleanup(9);
+    if (!put_server_line(".",1,1)) exit_cleanup(9);
 
     /* article successfully read */
     log_msg(L_DEBUG,"(%d lines)", article_lines);
@@ -418,7 +461,7 @@ put_article(ARTHANDLE *article, char **reason)
 	    exit_cleanup(9);
 	}
     } else {
-	sprintf(status,"%d",CONT_POST); /* fake OK */
+	snprintf(status,sizeof(status),"%d",CONT_POST); /* fake OK */
     }
 
     switch (strtoul(status,&endptr,10)) {
@@ -470,7 +513,7 @@ put_article(ARTHANDLE *article, char **reason)
 	    exit_cleanup(9);
 	} 
     } else {
-	sprintf(status,"%d",OK_POSTED);
+	snprintf(status,sizeof(status),"%d",OK_POSTED);
     }
 
     switch (strtoul(status,&endptr,10)) {
@@ -539,10 +582,8 @@ put_article(ARTHANDLE *article, char **reason)
 static void 
 post_article(void)
 {
-    char buf[NNTP_STRLEN+1];
     progtitle("post: issuing POST");
-    sprintf(buf, "POST%s",newline);
-    if (!put_server(buf)) exit_cleanup(9);
+    if (!put_server_cmd("POST")) exit_cleanup(9);
 }
 
 /*
@@ -553,8 +594,8 @@ ihave_article(char *msgid)
 {
     char buf[NNTP_STRLEN+1];
     progtitle("post: issuing IHAVE");
-    sprintf(buf, "IHAVE %s%s", msgid,newline);
-    if (!put_server(buf)) exit_cleanup(9);
+    snprintf(buf,sizeof(buf),"IHAVE %s", msgid);
+    if (!put_server_cmd(buf)) exit_cleanup(9);
 }
 
 /*
@@ -599,6 +640,67 @@ log_to_file(char *articlename, char *ok)
     unlock_one(lock_id);
 }
 
+/*
+ *  kill article, for various reasons
+ */
+void
+kill_article(char *articlename, ARTHANDLE *article, char *reason)
+{
+    char *to;
+
+    log_msg(L_ERR,"failed article \"%s\" killed",articlename);
+    if (!bounce || !bounce[0] || strcmp(bounce,"poster")==0) {
+	/* return to sender */
+	if (!msgsender[0]) {
+	    log_msg(L_ERR,"no From-specification in \"%s\"",
+						  articlename);
+	    to = 0;
+	} else {
+	    to = msgsender;
+	}
+    } else if (strcmp(bounce,"none")==0) {
+	to = 0;
+    } else {
+	/* bounce address specified */
+	to = bounce;
+    }
+    if (to) {
+	++bounced_articles;
+	log_msg(L_ERR,"bounce message to %s",to);
+	if (!bounce_msg(to,article->data,article->len,
+		      article->arrived,articlename,msgid,reason)) {
+	    /* BUG: what ever shall we do? */
+	    log_msg(L_ERR,"bounce failed");
+	}
+    }
+}
+
+/*
+ *  we need storage management now
+ *  return string if there are problems
+ */
+static char *
+need_sm(void)
+{
+    if (!SM_open) {
+	/* NOTE: below, "int" should be "BOOL", but various installations
+	 *       may or may not typedef BOOL
+	 */
+	static int value = 0; /* read/only access */
+
+	if (!SMsetup(SM_RDWR,(void *)&value)) {
+	    log_msg(L_ERR,"can't setup storage-API: %s",SMerrorstr);
+	    return "Storage-API error";
+	}
+	if (!SMinit()) {
+	    log_msg(L_ERR,"can't initialize storage-API: %s",SMerrorstr);
+	    return "Storage-API error";
+	}
+	SM_open = 1;
+    }
+    return NULL;
+}
+
 /*
  *  submit articles to the currently open NNTP server socket.
  *  return string if article should be removed from outgoing batch
@@ -608,37 +710,35 @@ submit_article(char *articlename)
 {
     ARTHANDLE *article;
     long age;
-    char *ok;
+    char *err;
     char *id;
-    char *to;
     char *reason;
     int is_api = 0;
 
     progtitle("post: reading article");
 
     if (IsToken(articlename)) {
-	/* Storage-API */
+	/* use  Storage-API */
 	TOKEN art_token;
 
+	if ((err = need_sm())) return err;
+
 	is_api = 1;
 	art_token = TextToToken(articlename);
 
 	log_msg(L_DEBUG,"reading API %s", articlename);
 
-	if (!SM_open) {
-	    BOOL value = 0; /* only need read/only access */
-
-	    SMsetup(SM_RDWR,(void *)&value);
-	    if (!SMinit()) {
-		log_msg(L_ERR,"can't initialize storage-API: %s",SMerrorstr);
-		return "Storage-API error";
+	/* better error reporting, by Andres Metzler <ametzler@logic.univie.ac.at> */
+	if ((article = SMretrieve(art_token, RETR_ALL)) == NULL) {
+	    /* filter by Jochen Schmitt <Jochen@herr-schmitt-de> */
+	    if ((SMerrno != SMERR_NOENT) && (SMerrno != SMERR_UNINIT)) {
+		log_msg(L_ERR,"Could not retrieve article: %s", SMerrorstr);
+		return "Retrieve error";
 	    }
-	    SM_open = 1;
 	}
-	article = SMretrieve(art_token, RETR_ALL);
 
     } else if (articlename[0] == '@' && 
-	       articlename[strlen(articlename)] == '@') {
+	       articlename[strlen(articlename)-1] == '@') {
 	/* storage-API type of entry, but no support */
 	log_msg(L_ERR,"no storage-API support for \"%s\"",articlename);
 	return "No support for storage-API";
@@ -656,32 +756,39 @@ submit_article(char *articlename)
 
     if (!article) {
 	/* article is missing - throw it away */
-	log_msg(L_ERR,"can't find article \"%s\": %s",articlename,SMerrorstr);
+	log_msg(L_ERR,"can't find article \"%s\"",articlename);
 	++missing_articles;
-	ok = "Missing";
+	err = "Missing";
     } else {
-	if (ihave_opt) {
-	    /* use ihave */
-	    if (!(id = sniff_article(article))) {
-		log_msg(L_ERR,"article \"%s\" lacks a message ID",articlename);
-		++missing_articles;
-		ok = "Missing-ID";
-	    } else {
-		ihave_article(id);
-		ok = put_article(article,&reason);
-	    }
+	if (!sniff_article(article,&id,&reason)) {
+	    /* something is not like it should be: kill and possibly bounce */
+	    ++failed_articles;
+	    kill_article(articlename,article,reason);
+	    err = "Malformed";
 	} else {
-	    /* request post */
-	    /* BUG: check if post_allowed? */
-	    post_article();
+	    if (ihave_opt) {
+		/* use ihave */
+		if (!id) {
+		    log_msg(L_ERR,"article \"%s\" lacks a message ID",articlename);
+		    ++missing_articles;
+		    err = "Missing-ID";
+		} else {
+		    ihave_article(id);
+		    err = put_article(article,&reason);
+		}
+	    } else {
+		/* request post */
+		/* BUG: check if post_allowed? */
+		post_article();
 
-	    /* and do it */
-	    ok = put_article(article,&reason);
+		/* and do it */
+		err = put_article(article,&reason);
+	    }
 	}
     }
 
-    if (ok) {
-	log_to_file(articlename,ok);
+    if (err) {
+	log_to_file(articlename,err);
     } else {
 	if (failtime) {
 	    /* timeout message... */
@@ -692,32 +799,8 @@ submit_article(char *articlename)
 
 	    log_msg(L_DEBUG,"article is %ds old, limit is %ds", age, failtime);
 	    if (age > failtime) {
-		log_msg(L_ERR,"failed article \"%s\" killed",articlename);
-		ok = "Failed";
-		if (!bounce || !bounce[0] || strcmp(bounce,"poster")==0) {
-		    /* return to sender */
-		    if (!msgsender[0]) {
-			log_msg(L_ERR,"no From-specification in \"%s\"",
-							      articlename);
-			to = 0;
-		    } else {
-			to = msgsender;
-		    }
-		} else if (strcmp(bounce,"none")==0) {
-		    to = 0;
-		} else {
-		    /* bounce address specified */
-		    to = bounce;
-		}
-		if (to) {
-		    ++bounced_articles;
-		    log_msg(L_ERR,"bounce message to %s",to);
-		    if (!bounce_msg(to,article->data,article->len,
-				  article->arrived,articlename,msgid,reason)) {
-			/* BUG: what ever shall we do? */
-			log_msg(L_ERR,"bounce failed");
-		    }
-		}
+		kill_article(articlename,article,reason);
+		err = "Failed";
 	    }
 	}
     }
@@ -726,7 +809,7 @@ submit_article(char *articlename)
 	else SIMfreearticle(article);
     }
 
-    return ok;
+    return err;
 }
 
 /*
