@@ -1,4 +1,4 @@
-/*  VER 123  TAB P   $Id: script.c,v 1.7 1998/09/09 07:32:13 src Exp $
+/*  VER 124  TAB P   $Id: script.c,v 1.8 1999/03/31 05:53:46 src Exp $
  *
  *  implement a very simple script for telnet
  *
@@ -6,6 +6,9 @@
  *  the GNU General Public License applies
  *
  *  $Log: script.c,v $
+ *  Revision 1.8  1999/03/31 05:53:46  src
+ *  Seperated MAXHEADERSIZE from NNTP_STRLEN
+ *
  *  Revision 1.7  1998/09/09 07:32:13  src
  *  Version 1.1
  *
@@ -24,7 +27,9 @@
 #  include <sys/socket.h>
 #endif
 
-static char chat_buf[NNTP_STRLEN+3];
+#define CHAT_STRLEN 512
+
+static char chat_buf[CHAT_STRLEN+3];
 static char *chat_match;
 static char *chat_send;
 
@@ -65,8 +70,8 @@ chat_line(SOCKET_D *sock)
 
     if (!(sock->f_chat)) return 0;
   again:
-    chat_buf[NNTP_STRLEN] = '\0';
-    if (!fgets(chat_buf,NNTP_STRLEN,sock->f_chat)) {
+    chat_buf[CHAT_STRLEN] = '\0';
+    if (!fgets(chat_buf,CHAT_STRLEN,sock->f_chat)) {
 	fclose(sock->f_chat);
 	sock->f_chat = 0;
 	return 0;
