@@ -1,4 +1,4 @@
-/*  VER 008  TAB P   $Id: stat.h,v 1.4 1998/09/09 07:32:14 src Exp $
+/*  VER 009  TAB P   $Id: stat.h,v 1.4.2.1 2003/01/21 20:19:45 egil Exp $
  *
  *  for fstat(), with the usual set of version dependencies
  *
@@ -6,6 +6,9 @@
  *  the GNU General Public License applies
  *
  *  $Log: stat.h,v $
+ *  Revision 1.4.2.1  2003/01/21 20:19:45  egil
+ *  mktemp() replaced by newstemp()
+ *
  *  Revision 1.4  1998/09/09 07:32:14  src
  *  Version 1.1
  *
@@ -13,7 +16,9 @@
  *  newsx version 1.0
  */
 
-#include <sys/stat.h>
+#if HAVE_SYS_STAT_H
+#  include <sys/stat.h>
+#endif
 
 #ifndef S_ISREG
 #  ifdef S_IFMT
