@@ -1,4 +1,4 @@
-/*  VER 006  TAB P   $Id: statistics.h,v 1.4 1998/09/09 07:32:14 src Exp $
+/*  VER 010  TAB P   $Id: statistics.h,v 1.7 1999/03/16 17:35:38 src Exp $
  *
  *  statistics 
  *
@@ -6,6 +6,15 @@
  *  the GNU General Public License applies
  *
  *  $Log: statistics.h,v $
+ *  Revision 1.7  1999/03/16 17:35:38  src
+ *  Version 1.4pre
+ *
+ *  Revision 1.6  1999/03/04 17:19:27  src
+ *  Fix for removed groups that weren't
+ *
+ *  Revision 1.5  1998/11/21 19:14:24  src
+ *  Added --filter option
+ *
  *  Revision 1.4  1998/09/09 07:32:14  src
  *  Version 1.1
  *
@@ -28,6 +37,7 @@ long unseen_groups;             /* groups not seen before */
 long unavailable_groups;        /* groups not on server */
 long already_articles;          /* number of articles already read */
 long history_articles;          /* number of articles in history database */
-long mfilter_articles;          /* number of articles filtered by message ID */
+long filter_articles;           /* number of articles filtered */
+long fake_articles;             /* number of articles filtered as fake */
 long net_bytecount;             /* total size of articles */
 long gross_bytecount;           /* total size of NNTP traffic */
