@@ -1,4 +1,4 @@
-/*  TAB P   VER 045   $Id: tune.h,v 1.8 1998/09/09 07:32:15 src Exp $
+/*  TAB P   VER 046   $Id: tune.h,v 1.9 1999/04/05 19:01:51 src Exp $
  *
  *  configuration
  *  tune as required
@@ -7,6 +7,9 @@
  *  the GNU General Public License applies
  *
  *  $Log: tune.h,v $
+ *  Revision 1.9  1999/04/05 19:01:51  src
+ *  Lock for scanlogs
+ *
  *  Revision 1.8  1998/09/09 07:32:15  src
  *  Version 1.1
  *
@@ -26,8 +29,13 @@
 #ifndef LOCKTIME
 #  define LOCKTIME TIMEOUT  /* for lockfile */
 #endif
+#ifndef SCANLOGTIME
+#  define SCANLOGTIME (3*TIMEOUT) /* for scanlogs lockfile */
+#endif
 
-#define LOCKDELTA    10     /* poll cycle: 10 seconds */
+#ifndef LOCKDELTA
+#  define LOCKDELTA  5      /* poll cycle: 5 seconds */
+#endif
 #define URGENT_TIMEOUT 1    /* when an error already has happened */
 
 /*
